@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_view.c,v 1.46.2.7 2004/06/30 09:28:13 fuyu Exp $
+ * $Id: bbs_thread_view.c,v 1.46.2.11 2004/11/13 12:40:52 fuyu Exp $
  */
 
 #include "config.h"
@@ -64,10 +64,8 @@ static void bbs_thread_view_realize(GtkWidget *widget);
 
 static gboolean bbs_thread_view_motion_notify(GtkWidget *widget,
 					      GdkEventMotion *event);
-#if GRAB_FOCUS_ON_ENTER_NOTIFY
 static gboolean bbs_thread_view_enter_notify(GtkWidget *widget,
 					     GdkEventCrossing *event);
-#endif
 static gboolean bbs_thread_view_leave_notify(GtkWidget *widget,
 					     GdkEventCrossing *event);
 static gboolean bbs_thread_view_button_press(GtkWidget *widget,
@@ -452,9 +450,7 @@ bbs_thread_view_class_init(BBSThreadViewClass *klass)
 
   widget_class->realize = bbs_thread_view_realize;
   widget_class->motion_notify_event = bbs_thread_view_motion_notify;
-#if GRAB_FOCUS_ON_ENTER_NOTIFY
   widget_class->enter_notify_event = bbs_thread_view_enter_notify;
-#endif
   widget_class->leave_notify_event = bbs_thread_view_leave_notify;
   widget_class->button_press_event = bbs_thread_view_button_press;
   widget_class->button_release_event = bbs_thread_view_button_release;
@@ -554,6 +550,12 @@ bbs_thread_view_destroy(GtkObject *object)
   fprintf(stderr, "bbs_thread_view_destroy(%p)\n", object);
 #endif
 
+  if (view->normal_cursor != NULL)
+    {
+      gdk_cursor_unref(view->normal_cursor);
+      view->normal_cursor = NULL;
+    }
+
   if (view->ibeam_cursor != NULL)
     {
       gdk_cursor_unref(view->ibeam_cursor);
@@ -609,6 +611,10 @@ bbs_thread_view_realize(GtkWidget *widget)
   display = gtk_widget_get_display(widget);
   view = BBS_THREAD_VIEW(widget);
 
+  if (view->normal_cursor != NULL)
+    gdk_cursor_unref(view->normal_cursor);
+  view->normal_cursor = gdk_cursor_new_for_display(display, GDK_LEFT_PTR);
+
   if (view->ibeam_cursor != NULL)
     gdk_cursor_unref(view->ibeam_cursor);
   view->ibeam_cursor = gdk_cursor_new_for_display(display, GDK_XTERM);
@@ -616,6 +622,8 @@ bbs_thread_view_realize(GtkWidget *widget)
   if (view->hand_cursor != NULL)
     gdk_cursor_unref(view->hand_cursor);
   view->hand_cursor = gdk_cursor_new_for_display(display, GDK_HAND2);
+
+  view->nonlink_cursor = NULL;
 }
 
 
@@ -652,6 +660,7 @@ text_view_get_iter_from_event(GtkTextView *text_view, GtkTextIter *iter,
     }
 
   gtk_text_view_get_iter_at_location(text_view, iter, buf_x, buf_y);
+
   return TRUE;
 }
 
@@ -734,7 +743,7 @@ emit_link_mouse_out(BBSThreadView *view, GdkEventAny *event)
 {
   gdk_window_set_cursor(gtk_text_view_get_window(GTK_TEXT_VIEW(view),
 						 GTK_TEXT_WINDOW_TEXT),
-			view->ibeam_cursor);
+			view->nonlink_cursor);
 
   g_signal_emit(G_OBJECT(view),
 		bbs_thread_view_signals[LINK_MOUSE_OUT_SIGNAL],
@@ -762,6 +771,35 @@ bbs_thread_view_motion_notify(GtkWidget *widget, GdkEventMotion *event)
       GtkTextIter start;
       GtkTextIter end;
       gchar *text;
+      GdkRectangle rect;
+      GdkCursor *prev_cursor;
+      int x;
+      int y;
+
+      /* text_view_get_iter_from_event()ǤƤǤΤǾĹġ */
+      gtk_text_view_window_to_buffer_coords(text_view, GTK_TEXT_WINDOW_TEXT,
+					    event->x, event->y, &x, &y);
+
+      /* ޥݥ󥿤ʸξˤibeamꤹ */
+      gtk_text_view_get_iter_location(text_view, &iter, &rect);
+      prev_cursor = view->nonlink_cursor;
+      /*ʷ׻⤽rectƤ̯ġġ */
+      if (rect.x - rect.width <= x && x < rect.x + rect.width)
+	view->nonlink_cursor = view->ibeam_cursor;
+      else
+	view->nonlink_cursor = view->normal_cursor;
+
+      if (view->nonlink_cursor != prev_cursor && view->last_offset == -1)
+	gdk_window_set_cursor(gtk_text_view_get_window(text_view,
+						       GTK_TEXT_WINDOW_TEXT),
+			      view->nonlink_cursor);
+
+#if 0
+      fprintf(stderr,
+	      "buf_x=%d, buf_y=%d, rect = { x=%d, y=%d, w=%d, h=%d }\n",
+	      x, y, rect.x, rect.y, rect.width, rect.height);
+      /* (x <= buf_x && buf_x < x + width)ǤʤȤϥѤ褦 */
+#endif
 
       if (gtk_text_buffer_get_selection_bounds(view->text_buffer, &start, &end)
 	  && gtk_text_iter_in_range(&iter, &start, &end)
@@ -791,7 +829,7 @@ bbs_thread_view_motion_notify(GtkWidget *widget, GdkEventMotion *event)
 
 	      if (view->link_table != NULL
 		  && (link = g_hash_table_lookup(view->link_table,
-				(gconstpointer)start_offset)) != NULL)
+				(gconstpointer)(long)start_offset)) != NULL)
 		{
 		  emit_link_mouse_over(view, event, link);
 		  view->last_offset = start_offset;
@@ -819,18 +857,19 @@ bbs_thread_view_motion_notify(GtkWidget *widget, GdkEventMotion *event)
 }
 
 
-#if GRAB_FOCUS_ON_ENTER_NOTIFY
 static gboolean
 bbs_thread_view_enter_notify(GtkWidget *widget, GdkEventCrossing *event)
 {
-  gtk_widget_grab_focus(widget);
+  OchushaApplication *application = g_object_get_qdata(G_OBJECT(widget),
+						       application_id);
+  if (application != NULL && application->focus_follow_mouse)
+    gtk_widget_grab_focus(widget);
 
   if (GTK_WIDGET_CLASS(parent_class)->enter_notify_event != NULL)
     return (*GTK_WIDGET_CLASS(parent_class)->enter_notify_event)(widget,
 								 event);
   return FALSE;
 }
-#endif
 
 
 static gboolean
@@ -873,7 +912,7 @@ bbs_thread_view_button_press(GtkWidget *widget, GdkEventButton *event)
       const gchar *link
 	= (view->link_table != NULL
 	   ? (gchar *)g_hash_table_lookup(view->link_table,
-					  (gconstpointer)offset)
+					  (gconstpointer)(long)offset)
 	   : NULL);
       if (link != NULL)
 	g_signal_emit(G_OBJECT(view),
@@ -912,7 +951,7 @@ bbs_thread_view_button_release(GtkWidget *widget, GdkEventButton *event)
       const gchar *link
 	= (view->link_table != NULL
 	   ? (gchar *)g_hash_table_lookup(view->link_table,
-					  (gconstpointer)offset)
+					  (gconstpointer)(long)offset)
 	   : NULL);
 
       if (link != NULL)
@@ -1130,7 +1169,7 @@ bbs_thread_view_append_text_as_link(BBSThreadView *view,
   gtk_text_buffer_apply_tag(view->text_buffer, get_alt_link_tag(view),
 			    &start, &view->iter);
   g_hash_table_insert(view->link_table,
-		      (gpointer)start_offset, G_STRDUP(link));
+		      (gpointer)(long)start_offset, G_STRDUP(link));
 }
 
 
@@ -1157,7 +1196,7 @@ bbs_thread_view_append_text_as_sage(BBSThreadView *view,
   gtk_text_buffer_apply_tag(view->text_buffer, get_alt_sage_tag(view),
 			    &start, &view->iter);
   g_hash_table_insert(view->link_table,
-		      (gpointer)start_offset, G_STRDUP(link));
+		      (gpointer)(long)start_offset, G_STRDUP(link));
 }
 
 
@@ -1184,7 +1223,7 @@ bbs_thread_view_append_text_as_hidden_link(BBSThreadView *view,
   gtk_text_buffer_apply_tag(view->text_buffer, get_alt_hidden_link_tag(view),
 			    &start, &view->iter);
   g_hash_table_insert(view->link_table,
-		      (gpointer)start_offset, G_STRDUP(link));
+		      (gpointer)(long)start_offset, G_STRDUP(link));
 }
 
 
@@ -1215,7 +1254,8 @@ bbs_thread_view_append_widget(BBSThreadView *view, GtkWidget *widget,
 
   anchor_offset = gtk_text_iter_get_offset(&view->iter);
 
-  g_hash_table_insert(view->child_table, widget, (gpointer)anchor_offset);
+  g_hash_table_insert(view->child_table,
+		      widget, (gpointer)(long)anchor_offset);
 }
 
 
@@ -1231,7 +1271,7 @@ static void
 increment_values(gpointer key, int value, AdjustOffsetArgs *args)
 {
   if (value >= args->offset)
-    g_hash_table_replace(args->hash_table, key, (gpointer)(value + 1));
+    g_hash_table_replace(args->hash_table, key, (gpointer)(long)(value + 1));
 }
 
 
@@ -1239,9 +1279,10 @@ static gboolean
 update_link_table_increment(int offset, char *url, AdjustOffsetArgs *args)
 {
   if (offset >= args->offset)
-    g_hash_table_insert(args->new_hash_table, (gpointer)(offset + 1), url);
+    g_hash_table_insert(args->new_hash_table,
+			(gpointer)(long)(offset + 1), url);
   else
-    g_hash_table_insert(args->new_hash_table, (gpointer)offset, url);
+    g_hash_table_insert(args->new_hash_table, (gpointer)(long)offset, url);
 
   return TRUE;
 }
@@ -1280,7 +1321,8 @@ bbs_thread_view_insert_widget_at_offset(BBSThreadView *view, GtkWidget *widget,
   args.hash_table = view->child_table;
   g_hash_table_foreach(view->child_table, (GHFunc)increment_values, &args);
 
-  g_hash_table_insert(view->child_table, widget, (gpointer)anchor_offset);
+  g_hash_table_insert(view->child_table,
+		      widget, (gpointer)(long)anchor_offset);
 
   args.hash_table = view->link_table;
   args.new_hash_table = g_hash_table_new_full(NULL, NULL, NULL, TRACE_FREE);
@@ -1297,7 +1339,7 @@ static void
 decrement_values(gpointer key, int value, AdjustOffsetArgs *args)
 {
   if (value >= args->offset)
-    g_hash_table_replace(args->hash_table, key, (gpointer)(value - 1));
+    g_hash_table_replace(args->hash_table, key, (gpointer)(long)(value - 1));
 }
 
 
@@ -1305,9 +1347,10 @@ static gboolean
 update_link_table_decrement(int offset, char *url, AdjustOffsetArgs *args)
 {
   if (offset >= args->offset)
-    g_hash_table_insert(args->new_hash_table, (gpointer)(offset - 1), url);
+    g_hash_table_insert(args->new_hash_table,
+			(gpointer)(long)(offset - 1), url);
   else
-    g_hash_table_insert(args->new_hash_table, (gpointer)offset, url);
+    g_hash_table_insert(args->new_hash_table, (gpointer)(long)offset, url);
 
   return TRUE;
 }
@@ -1324,7 +1367,7 @@ bbs_thread_view_remove_widget(BBSThreadView *view, GtkWidget *widget)
   g_return_if_fail(IS_BBS_THREAD_VIEW(view));
   g_return_if_fail(GTK_IS_WIDGET(widget));
 
-  anchor_offset = (guint)g_hash_table_lookup(view->child_table, widget);
+  anchor_offset = (guint)(long)g_hash_table_lookup(view->child_table, widget);
   g_return_if_fail(anchor_offset != 0);
 
   g_hash_table_remove(view->child_table, widget);
