@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_ui.c,v 1.92.2.9 2005/02/18 17:33:16 fuyu Exp $
+ * $Id: boardlist_ui.c,v 1.92.2.11 2005/09/06 11:16:16 fuyu Exp $
  */
 
 #define _BOARDLIST_UI_C_ 1
@@ -2181,8 +2181,8 @@ new_thread_dialog_response_cb(GtkWidget *dialog, int response_id,
 	  gdk_threads_leave();
 	  result = ochusha_bulletin_board_create_new_thread(board,
 						application->broker,
-						title, &response,
-						application->dolib_use_id_for_posting);
+						title, &response);
+
 	  gdk_threads_enter();
 	  g_free(message);
 	  if (result)
@@ -2264,6 +2264,57 @@ new_thread_dialog_response_cb(GtkWidget *dialog, int response_id,
 }
 
 
+static void
+be_button_toggled_cb(GtkToggleButton *button, OchushaApplication *application)
+{
+  gboolean active = gtk_toggle_button_get_active(button);
+  OchushaBulletinBoard *board;
+
+  if (!active)
+    {
+      board = g_object_get_data(G_OBJECT(button), "board");
+      ochusha_bulletin_board_set_post_use_2ch_be(board, FALSE);
+      return;
+    }
+
+  if (application->config.session_id_2ch_be == NULL
+      && !ochusha_be_login(application))
+    {
+      gtk_toggle_button_set_active(button, FALSE);
+      return;
+    }
+
+  board = g_object_get_data(G_OBJECT(button), "board");
+  ochusha_bulletin_board_set_post_use_2ch_be(board, active);
+}
+
+
+static void
+maru_button_toggled_cb(GtkToggleButton *button,
+		       OchushaApplication *application)
+{
+  gboolean active = gtk_toggle_button_get_active(button);
+  OchushaBulletinBoard *board;
+
+  if (!active)
+    {
+      board = g_object_get_data(G_OBJECT(button), "board");
+      ochusha_bulletin_board_set_post_use_2ch_viewer(board, FALSE);
+      return;
+    }
+
+  if (application->config.session_id_2ch == NULL
+      && !ochusha_viewer_login(application))
+    {
+      gtk_toggle_button_set_active(button, FALSE);
+      return;
+    }
+
+  board = g_object_get_data(G_OBJECT(button), "board");
+  ochusha_bulletin_board_set_post_use_2ch_viewer(board, active);
+}
+
+
 static GtkWidget *
 create_new_thread_dialog(OchushaApplication *application,
 			 OchushaBulletinBoard *board)
@@ -2331,6 +2382,52 @@ create_new_thread_dialog(OchushaApplication *application,
   editor = response_editor_new();
   response_editor = RESPONSE_EDITOR(editor);
 
+  if (board->bbs_type == OCHUSHA_BBS_TYPE_2CH
+      || board->bbs_type == OCHUSHA_BBS_TYPE_2CH_BE)
+    {
+      if (application->be_id != NULL && *application->be_id != '\0'
+	  && application->be_passwd != NULL && *application->be_passwd != '\0')
+	{
+	  GtkWidget *be_button = gtk_toggle_button_new_with_label(_("Be"));
+	  gtk_box_pack_start(response_editor->hbox,
+			     be_button, FALSE, FALSE, 0);
+	  g_object_set_data(G_OBJECT(new_thread_dialog),
+			    "be_button", be_button);
+	  g_object_set_data(G_OBJECT(be_button), "board", board);
+	  if (board->bbs_type == OCHUSHA_BBS_TYPE_2CH_BE)
+	    {
+	      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(be_button), TRUE);
+	      gtk_widget_set_sensitive(be_button, FALSE);
+	    }
+	  else
+	    {
+	      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(be_button),
+			ochusha_bulletin_board_get_post_use_2ch_be(board,
+							&application->config));
+	    }
+	  g_signal_connect(G_OBJECT(be_button), "toggled",
+			   G_CALLBACK(be_button_toggled_cb), application);
+	}
+
+      if (application->dolib_id != NULL && *application->dolib_id != '\0'
+	  && application->dolib_passwd != NULL
+	  && *application->dolib_passwd != '\0')
+	{
+	  GtkWidget *maru_button;
+	  maru_button = gtk_toggle_button_new_with_label(_("Viewer"));
+	  gtk_box_pack_start(response_editor->hbox,
+			     maru_button, FALSE, FALSE, 0);
+	  g_object_set_data(G_OBJECT(new_thread_dialog),
+			    "maru_button", maru_button);
+	  g_object_set_data(G_OBJECT(maru_button), "board", board);
+	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(maru_button),
+			ochusha_bulletin_board_get_post_use_2ch_viewer(board,
+							&application->config));
+	  g_signal_connect(G_OBJECT(maru_button), "toggled",
+			   G_CALLBACK(maru_button_toggled_cb), application);
+	}
+    }
+
   if (board_info->last_name != NULL)
     {
       response_editor_add_name(response_editor, board_info->last_name);
