@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_view.c,v 1.35.2.3 2004/06/16 05:28:59 fuyu Exp $
+ * $Id: boardlist_view.c,v 1.35.2.6 2005/02/18 19:12:44 fuyu Exp $
  */
 
 #include "config.h"
@@ -86,10 +86,8 @@ static void tree_view_row_expanded_cb(GtkTreeView *tree_view,
 static void tree_view_row_collapsed_cb(GtkTreeView *tree_view,
 				       GtkTreeIter *iter, GtkTreePath *path,
 				       BoardlistView *view);
-#if GRAB_FOCUS_ON_ENTER_NOTIFY
 static gboolean boardlist_view_enter_notify(GtkWidget *widget,
 					    GdkEventCrossing *event);
-#endif
 static gboolean boardlist_view_button_press(GtkWidget *widget,
 					    GdkEventButton *event);
 static gboolean boardlist_view_button_release(GtkWidget *widget,
@@ -739,9 +737,7 @@ boardlist_view_class_init(BoardlistViewClass *klass)
 			       G_TYPE_ENUM, GTK_MOVEMENT_PAGES,
 			       G_TYPE_INT, -1);
 
-#if GRAB_FOCUS_ON_ENTER_NOTIFY
   widget_class->enter_notify_event = boardlist_view_enter_notify;
-#endif
   widget_class->button_press_event = boardlist_view_button_press;
   widget_class->button_release_event = boardlist_view_button_release;
 
@@ -1592,18 +1588,19 @@ boardlist_view_new(void)
 }
 
 
-#if GRAB_FOCUS_ON_ENTER_NOTIFY
 static gboolean
 boardlist_view_enter_notify(GtkWidget *widget, GdkEventCrossing *event)
 {
-  gtk_widget_grab_focus(widget);
+  OchushaApplication *application = g_object_get_qdata(G_OBJECT(widget),
+						       application_id);
+  if (application != NULL && application->focus_follow_mouse)
+    gtk_widget_grab_focus(widget);
 
   if (GTK_WIDGET_CLASS(parent_class)->enter_notify_event != NULL)
     return (*GTK_WIDGET_CLASS(parent_class)->enter_notify_event)(widget,
 								 event);
   return FALSE;
 }
-#endif
 
 
 static gboolean
@@ -1976,9 +1973,6 @@ decorate_boardlist_entry(GtkTreeViewColumn *tree_column,
 			 GtkTreeIter *iter, gpointer view)
 {
   guint state;
-  GValue st = { 0, };
-  GValue bg = { 0, };
-  GValue fg = { 0, };
   const char *color;
 
   g_return_if_fail(gtk_tree_store_iter_is_valid(GTK_TREE_STORE(tree_model),
@@ -1991,57 +1985,29 @@ decorate_boardlist_entry(GtkTreeViewColumn *tree_column,
 
   if ((state & BOARDLIST_ROW_STATE_HIDDEN) != 0)
     {
-      g_value_init(&st, G_TYPE_BOOLEAN);
-      g_value_set_boolean(&st, TRUE);
-      g_object_set_property((GObject *)renderer, "strikethrough", &st);
-      g_object_set_property((GObject *)renderer, "strikethrough_set", &st);
-
-      color = boardlist_view_get_color(view, 3);
-      g_value_init(&bg, G_TYPE_STRING);
-      g_value_set_static_string(&bg, color);
-      g_object_set_property((GObject *)renderer, "cell_background", &bg);
-
-      if ((state & BOARDLIST_ROW_STATE_KILLED) != 0)
-	{
-	  color = boardlist_view_get_color(view, 3);
-	  g_value_init(&fg, G_TYPE_STRING);
-	  g_value_set_static_string(&fg, color);
-	  g_object_set_property((GObject *)renderer, "foreground", &fg);
-	}
+      if ((state & BOARDLIST_ROW_STATE_KILLED) == 0)
+	color = boardlist_view_get_color(view, 1);
       else
-	{
-	  color = boardlist_view_get_color(view, 1);
-	  g_value_init(&fg, G_TYPE_STRING);
-	  g_value_set_static_string(&fg, color);
-	  g_object_set_property((GObject *)renderer, "foreground", &fg);
-	}
+	color = boardlist_view_get_color(view, 3);
+      g_object_set((GObject *)renderer,
+		   "strikethrough", TRUE,
+		   "strikethrough_set", TRUE,
+		   "cell_background", boardlist_view_get_color(view, 3),
+		   "foreground", color,
+		   NULL);
     }
   else
     {
-      g_value_init(&st, G_TYPE_BOOLEAN);
-      g_value_set_boolean(&st, FALSE);
-      g_object_set_property((GObject *)renderer, "strikethrough", &st);
-      g_object_set_property((GObject *)renderer, "strikethrough_set", &st);
-
-      color = boardlist_view_get_color(view, 2);
-      g_value_init(&bg, G_TYPE_STRING);
-      g_value_set_static_string(&bg, color);
-      g_object_set_property((GObject *)renderer, "cell_background", &bg);
-
-      if ((state & BOARDLIST_ROW_STATE_KILLED) != 0)
-	{
-	  color = boardlist_view_get_color(view, 2);
-	  g_value_init(&fg, G_TYPE_STRING);
-	  g_value_set_static_string(&fg, color);
-	  g_object_set_property((GObject *)renderer, "foreground", &fg);
-	}
+      if ((state & BOARDLIST_ROW_STATE_KILLED) == 0)
+	color = boardlist_view_get_color(view, 0);
       else
-	{
-	  color = boardlist_view_get_color(view, 0);
-	  g_value_init(&fg, G_TYPE_STRING);
-	  g_value_set_static_string(&fg, color);
-	  g_object_set_property((GObject *)renderer, "foreground", &fg);
-	}
+	color = boardlist_view_get_color(view, 2);
+      g_object_set((GObject *)renderer,
+		   "strikethrough", FALSE,
+		   "strikethrough_set", FALSE,
+		   "cell_background", boardlist_view_get_color(view, 2),
+		   "foreground", color,
+		   NULL);
     }
 }
 
