@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_view.h,v 1.18 2004/01/15 02:18:05 fuyu Exp $
+ * $Id: boardlist_view.h,v 1.18.2.1 2004/06/11 12:02:05 fuyu Exp $
  */
 
 #ifndef _BOARDLIST_VIEW_H_
@@ -45,6 +45,19 @@ extern "C" {
 #define IS_BOARDLIST_VIEW_CLASS(klass)		(G_TYPE_CHECK_CLASS_TYPE((klass), BOARDLIST_VIEW_TYPE))
 #define BOARDLIST_VIEW_GET_CLASS(obj)		(G_TYPE_INSTANCE_GET_CLASS((obj), BOARDLIST_VIEW_TYPE, BoardlistViewClass))
 
+#define BOARDLIST_VIEW_ACTION_TYPE		(boardlist_view_action_get_type())
+
+typedef enum
+{
+  TOGGLE_HIDDEN_STATE,
+  KILL_ITEM,
+  ADVANCE_VIEW,
+  BACK_VIEW,
+} BoardlistViewAction;
+
+
+GType boardlist_view_action_get_type(void) G_GNUC_CONST;
+
 
 typedef struct _BoardlistView BoardlistView;
 typedef struct _BoardlistViewClass BoardlistViewClass;
@@ -93,7 +106,8 @@ struct _BoardlistViewClass
   gboolean (*back_view)(BoardlistView *view);
 
   void (*do_on_selection)(BoardlistView *view, int what_to_do);
-  void (*do_on_item_at_cursor)(BoardlistView *view, int what_to_do);
+  void (*do_on_item_at_cursor)(BoardlistView *view,
+			       BoardlistViewAction what_to_do);
 
   void (*uri_dropped)(BoardlistView *view,
 		      OchushaBoardCategory *category,
@@ -102,7 +116,7 @@ struct _BoardlistViewClass
 };
 
 
-GType boardlist_view_get_type(void);
+GType boardlist_view_get_type(void) G_GNUC_CONST;
 GtkWidget *boardlist_view_new(void);
 void boardlist_view_open(BoardlistView *view, GSList *category_list,
 			 gboolean really_hide_hidden_items);
