@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bulletin_board_ui.h,v 1.28 2004/01/15 02:18:05 fuyu Exp $
+ * $Id: bulletin_board_ui.h,v 1.28.2.2 2004/09/24 16:14:52 fuyu Exp $
  */
 
 #ifndef _BULLETIN_BOARD_UI_H_
@@ -36,6 +36,7 @@
 
 #include "boardlist_view.h"
 #include "icon_label.h"
+#include "response_editor.h"
 #include "threadlist_filter.h"
 #include "threadlist_view.h"
 
@@ -133,7 +134,7 @@ void ochusha_open_kako_thread(OchushaApplication *application,
 			      OchushaBulletinBoard *board, const char *url,
 			      gboolean in_tab);
 
-void write_response(OchushaApplication *application);
+void write_response(OchushaApplication *application, int res_num);
 
 void refresh_threadlist_view(OchushaApplication *application,
 			     OchushaBulletinBoard *board);
@@ -159,6 +160,10 @@ void bookmark_remove_thread(OchushaBulletinBoard *board,
 			    OchushaBBSThread *thread,
 			    OchushaApplication *application);
 
+#if GTK_MINOR_VERSION > 2
+void setup_aalist(OchushaApplication *application, ResponseEditor *editor);
+#endif
+
 #ifdef __cplusplus
 } // extern "C"
 #endif
