@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: download_ui.c,v 1.11.2.6 2004/11/09 23:03:23 fuyu Exp $
+ * $Id: download_ui.c,v 1.11.2.7 2005/09/04 07:27:51 fuyu Exp $
  */
 
 #include "config.h"
@@ -406,6 +406,9 @@ open_download_dialog(OchushaApplication *application, const char *url,
 }
 
 
+#define COMMAND_LINE_BUFFER_SIZE	4096
+
+
 void
 ochusha_download_url(OchushaApplication *application, const char *url)
 {
@@ -415,6 +418,39 @@ ochusha_download_url(OchushaApplication *application, const char *url)
   if (*url == '\0')
     return;
 
+  if (!application->use_internal_downloader)
+    {
+      char command_line[COMMAND_LINE_BUFFER_SIZE];
+      char *real_url = ochusha_utils_hack_known_special_url(url);
+
+      if (real_url != NULL)
+	url = real_url;
+
+      if (snprintf(command_line, COMMAND_LINE_BUFFER_SIZE,
+		   application->downloader_template, url)
+	  < COMMAND_LINE_BUFFER_SIZE)
+	{
+	  GError *error = NULL;
+	  if (!ochusha_utils_spawn_command_line(command_line, &error))
+	    {
+	      /* TODO: 顼ɽ */
+	      fprintf(stderr, "spawning error[%s]: %s (%d)\n",
+		      command_line, error->message, error->code);
+	    }
+	  if (error != NULL)
+	    g_error_free(error);
+	}
+      else
+	{
+	  /* TODO: 顼ɽ */
+	  fprintf(stderr, "too long URL: %s\n", url);
+	}
+      if (real_url != NULL)
+	G_FREE(real_url);
+
+      return;
+    }
+
   scheme = ochusha_utils_url_extract_scheme(url);
   if (scheme == NULL)
     return;
