@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: image_ui.c,v 1.5.2.14 2004/06/14 07:52:14 fuyu Exp $
+ * $Id: image_ui.c,v 1.5.2.17 2005/07/31 09:01:39 fuyu Exp $
  */
 
 #include "config.h"
@@ -50,6 +50,7 @@
 
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <unistd.h>
 #include <utime.h>
 
 /* #undef DEBUG_CACHE		0 */
@@ -116,7 +117,13 @@ image_info_free(ImageInfo *info)
   /* gdk_threads_enter()ĶƤӽФ */
   g_free(info->url);
   if (info->loader != NULL)
-    g_object_unref(info->loader);
+    {
+#if 0
+      fprintf(stderr, "image_info_free: loader(%p)->ref_count=%d\n",
+	      info->loader, ((GObject *)info->loader)->ref_count);
+#endif
+      g_object_unref(info->loader);
+    }
   if (info->animation != NULL)
     g_object_unref(info->animation);
   if (info->pixbuf != NULL)
@@ -486,6 +493,10 @@ set_pixbuf(ImageInfo *image_info)
     }
 
   image_info->loader = NULL;
+#if 0
+  fprintf(stderr, "set_pixbuf: loader(%p)->ref_count=%d\n",
+	  loader, ((GObject *)loader)->ref_count);
+#endif
   g_object_unref(loader);
 
   if (image_info->widget_list == NULL
@@ -529,8 +540,19 @@ size_prepared_cb(GdkPixbufLoader *loader, int width, int height,
       width *= width_scale;
       height *= width_scale;
     }
+
   if (width < 0 || height < 0)
-    return;
+    return;	/* ɽ꤬󸽼Ūäꤷoverflowʾ */
+
+  /*
+   * ü˽Ĺ䲣Ĺʲ̾褦Ȥ̡⤵0ˤʤ
+   * GTK+GdkPixbufLoaderΥХåեŬڤ˳ݤǤʤ褦롣
+   * assertƤʤΤġġٹ𤬽ФƤä᤯դΤˤʡ
+   */
+  if (width == 0)
+    width = 1;	
+  if (height == 0)
+    height = 1;
 
   gdk_pixbuf_loader_set_size(loader, width, height);
 
@@ -630,6 +652,10 @@ download_image(WorkerThread *employee, gpointer args)
 
   OCHU_OBJECT_UNREF(buffer);
 
+#if 0
+  fprintf(stderr, "download_image: loader(%p)->ref_count=%d\n",
+	  loader, ((GObject *)loader)->ref_count);
+#endif
   g_object_unref(loader);
 }
 
@@ -775,6 +801,9 @@ ochusha_download_image(OchushaApplication *application, const char *url,
     return NULL;
 
   loader = gdk_pixbuf_loader_new();
+#if 0
+  fprintf(stderr, "ochusha_download_image(): loader=%p\n", loader);
+#endif
   image = gtk_image_new_from_stock(OCHUSHA_STOCK_MISSING_IMAGE,
 				   GTK_ICON_SIZE_DIALOG);
   image_info = image_info_new(url, loader, image);
