@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.h,v 1.76.2.8 2005/06/06 19:00:13 fuyu Exp $
+ * $Id: ochusha_ui.h,v 1.76.2.12 2005/09/06 12:21:53 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_UI_H_
@@ -43,6 +43,8 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 
+#include <unistd.h>
+
 
 #define ENABLE_DEBUG_CONSOLE						1
 
@@ -77,6 +79,7 @@
 #define OCHUSHA_DEFAULT_ENABLE_POPUP_TITLE				FALSE
 #define OCHUSHA_DEFAULT_ENABLE_POPUP_RESPONSE				TRUE
 #define OCHUSHA_DEFAULT_ENABLE_POPUP_ID					FALSE
+#define OCHUSHA_DEFAULT_ENABLE_POPUP_THREAD_TITLE			FALSE
 
 #define OCHUSHA_DEFAULT_POPUP_DELAY					500
 #define OCHUSHA_DEFAULT_POPUP_CLOSE_DELAY				100
@@ -90,6 +93,8 @@
 #define OCHUSHA_DEFAULT_SHOW_MAILTO_MODE	THREAD_VIEW_MAILTO_MODE_DEFAULT
 
 #define OCHUSHA_DEFAULT_WEB_BROWSER_TEMPLATE	"mozilla -raise -remote \"openURL(%s,new-window)\""
+#define OCHUSHA_DEFAULT_DOWNLOADER_TEMPLATE	"gftp-gtk %s"
+#define OCHUSHA_DEFAULT_USE_INTERNAL_DOWNLOAER				FALSE
 
 #define OCHUSHA_DEFAULT_INLINE_IMAGE_WIDTH				160
 #define OCHUSHA_DEFAULT_INLINE_IMAGE_HEIGHT				120
@@ -276,6 +281,7 @@ struct _OchushaApplication
   gboolean analyze_informal_links;
 
   gboolean enable_popup_id;
+  gboolean enable_popup_thread_title;
 
   /* Ϣ */
   int inline_image_width;
@@ -290,6 +296,10 @@ struct _OchushaApplication
   /* ֥֥饦Υޥɥ饤ƥץ졼 */
   char *web_browser_template;
 
+  /* Υޥɥ饤ƥץ졼 */
+  char *downloader_template;
+  gboolean use_internal_downloader;
+
 
   /* Υ桼ǥեȥե륿롼 */
   ThreadlistFilter user_default_filter;
@@ -344,7 +354,9 @@ struct _OchushaApplication
   char *dolib_passwd;
   gboolean dolib_save_passwd;
   gboolean dolib_login_at_startup;
+#if 0
   gboolean dolib_use_id_for_posting;
+#endif
 
 
   /* 2ch BeϢ */
@@ -373,6 +385,9 @@ void ochusha_create_new_category(OchushaApplication *application);
 void ochusha_add_board(OchushaApplication *application, const char *url);
 void ochusha_create_new_virtual_board(OchushaApplication *application);
 
+gboolean ochusha_be_login(OchushaApplication *application);
+gboolean ochusha_viewer_login(OchushaApplication *application);
+
 #ifdef __cplusplus
 } // extern "C"
 #endif
