@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: paned_notebook.h,v 1.8.2.2 2004/06/11 12:02:34 fuyu Exp $
+ * $Id: paned_notebook.h,v 1.8.2.3 2005/02/18 17:33:16 fuyu Exp $
  */
 
 #ifndef _PANED_NOTEBOOK_H_
@@ -85,9 +85,6 @@ struct _PanedNotebook
   /* toolbar_boxκ¦ */
   GtkToolbar *toolbar;
 
-  /* toolbar_boxα¦ */
-  GtkToolbar *right_toolbar;
-
 
   /* tool_bar */
   GtkWidget *left_arrow;
@@ -105,7 +102,6 @@ struct _PanedNotebook
   GtkComboBox *contents_menu;
   GtkListStore *contents_list;
 
-  GtkActionGroup *action_group;
   GtkUIManager *ui_manager;
 #endif
 
