@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: thread_proxy.c,v 1.10.2.2 2004/06/19 11:17:43 fuyu Exp $
+ * $Id: thread_proxy.c,v 1.10.2.3 2005/08/15 17:18:07 fuyu Exp $
  */
 
 #include "config.h"
@@ -107,8 +107,7 @@ static gboolean thread_proxy_preview_response(OchushaBBSThread *thread,
 static gboolean thread_proxy_post_supported(OchushaBBSThread *thread);
 static gboolean thread_proxy_post_response(OchushaBBSThread *thread,
 					   OchushaNetworkBroker *broker,
-					   const OchushaBBSResponse *response,
-					   gboolean use_id);
+					   const OchushaBBSResponse *response);
 
 
 GType
@@ -458,8 +457,7 @@ thread_proxy_post_supported(OchushaBBSThread *thread)
 static gboolean
 thread_proxy_post_response(OchushaBBSThread *thread,
 			   OchushaNetworkBroker *broker,
-			   const OchushaBBSResponse *response,
-			   gboolean use_id)
+			   const OchushaBBSResponse *response)
 {
   ThreadProxy *proxy;
   g_return_val_if_fail(IS_THREAD_PROXY(thread), FALSE);
@@ -468,7 +466,7 @@ thread_proxy_post_response(OchushaBBSThread *thread,
   if (proxy->real_thread == NULL)
     return FALSE;
   return ochusha_bbs_thread_post_response(proxy->real_thread,
-					  broker, response, use_id);
+					  broker, response);
 }
 
 
