@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: threadlist_filter.c,v 1.14 2004/01/14 10:03:18 fuyu Exp $
+ * $Id: threadlist_filter.c,v 1.15.2.2 2005/02/18 19:12:44 fuyu Exp $
  */
 
 #include "config.h"
@@ -1090,7 +1090,8 @@ static void
 spin_button_value_changed_cb(GtkSpinButton *spin_button,
 			     ThreadlistFilterSetting *setting)
 {
-  setting->filter.ignore_threshold = gtk_spin_button_get_value(spin_button);
+  setting->filter.ignore_threshold
+    = gtk_spin_button_get_value_as_int(spin_button);
   g_signal_emit(G_OBJECT(setting),
 		threadlist_filter_setting_signals[CHANGED_SIGNAL],
 		0,
@@ -1480,34 +1481,19 @@ text_set_cell_data_available_rule(GtkTreeViewColumn *column,
 				  ThreadlistFilterSetting *setting)
 {
   /*  ThreadlistFilter *filter = &setting->filter; */
-  GValue src = { 0, };
-  GValue psrc = { 0, };
-  GValue text = { 0, };
-  GValue visible = { 0, };
   int rule;
   int priority;
 
-  gtk_tree_model_get_value(model, iter, FILTER_RULE, &src);
-  rule = g_value_get_int(&src);
-  gtk_tree_model_get_value(model, iter, FILTER_RULE_PRIORITY, &psrc);
-  priority = g_value_get_int(&psrc);
+  gtk_tree_model_get(model, iter,
+		     FILTER_RULE, &rule,
+		     FILTER_RULE_PRIORITY, &priority,
+		     -1);
 
-  g_value_init(&text, G_TYPE_STRING);
-  g_value_set_static_string(&text, get_threadlist_filter_rule_string(rule));
-  g_object_set_property((GObject *)renderer, "text", &text);
-
-#if 0
-  g_value_init(&visible, G_TYPE_BOOLEAN);
-  g_value_set_boolean(&visible, priority == -1);
-  g_object_set_property((GObject *)renderer, "visible", &visible);
-#else	/* XXX: ġɤ꤬ɤʤʡ */
-  g_value_init(&visible, G_TYPE_STRING);
-  if (priority != -1)
-    g_value_set_static_string(&visible, "gray50");
-  else
-    g_value_set_static_string(&visible, NULL);
-  g_object_set_property((GObject *)renderer, "foreground", &visible);
-#endif
+  /* XXX: gray30hardcodingΤǤʤɤ꤬ɤʤʡ */
+  g_object_set((GObject *)renderer,
+	       "text", get_threadlist_filter_rule_string(rule),
+	       "foreground", priority != -1 ? "gray30" : NULL,
+	       NULL);
 }
 
 
@@ -1519,16 +1505,12 @@ text_set_cell_data_applied_rule(GtkTreeViewColumn *column,
 				ThreadlistFilterSetting *setting)
 {
   /*  ThreadlistFilter *filter = &setting->filter; */
-  GValue src = { 0, };
-  GValue text = { 0, };
   int rule;
 
-  gtk_tree_model_get_value(model, iter, FILTER_RULE, &src);
-  rule = g_value_get_int(&src);
-
-  g_value_init(&text, G_TYPE_STRING);
-  g_value_set_static_string(&text, get_threadlist_filter_rule_string(rule));
-  g_object_set_property((GObject *)renderer, "text", &text);
+  gtk_tree_model_get(model, iter, FILTER_RULE, &rule, -1);
+  g_object_set((GObject *)renderer,
+	       "text", get_threadlist_filter_rule_string(rule),
+	       NULL);
 }
 
 
