@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: threadlist_view.h,v 1.36.2.3 2004/12/29 07:25:34 fuyu Exp $
+ * $Id: threadlist_view.h,v 1.36.2.4 2005/02/18 17:33:16 fuyu Exp $
  */
 
 #ifndef _THREADLIST_VIEW_H_
@@ -287,8 +287,6 @@ void threadlist_view_initialize_default_view(ThreadlistView *view);
 gboolean threadlist_view_open(ThreadlistView *view);
 void threadlist_view_close(ThreadlistView *view);
 void threadlist_view_show(ThreadlistView *view);
-void threadlist_view_freeze(ThreadlistView *view);
-void threadlist_view_chew(ThreadlistView *view);
 void threadlist_view_append_thread(ThreadlistView *view,
 				   OchushaBBSThread *thread,
 				   int num_shown, int num_unread,
