@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: virtual_board.c,v 1.21.2.1 2004/05/30 14:53:41 fuyu Exp $
+ * $Id: virtual_board.c,v 1.21.2.2 2004/06/13 22:55:27 fuyu Exp $
  */
 
 #include "config.h"
@@ -559,7 +559,7 @@ update_by_board(gpointer list_data, gpointer user_data)
   if (args->terminate_now)
     return;
 
-  OCHU_THREADS_ENTER();
+  gdk_threads_enter();
   buffer = ochusha_bulletin_board_get_threadlist_source(board, args->broker,
 							args->buffer,
 							args->mode);
@@ -568,7 +568,7 @@ update_by_board(gpointer list_data, gpointer user_data)
 					       &application->config,
 					       application->session_subdir,
 					       TRUE);
-  OCHU_THREADS_LEAVE();
+  gdk_threads_leave();
 
   if (!ochusha_bulletin_board_refresh_threadlist(OCHUSHA_BULLETIN_BOARD(list_data),
 						 buffer,
