@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: virtual_board.h,v 1.9 2004/01/24 07:04:14 fuyu Exp $
+ * $Id: virtual_board.h,v 1.9.2.1 2004/06/11 12:02:34 fuyu Exp $
  */
 
 #ifndef _VIRTUAL_BOARD_H_
@@ -73,7 +73,7 @@ struct _VirtualBoardClass
 };
 
 
-GType virtual_board_get_type(void);
+GType virtual_board_get_type(void) G_GNUC_CONST;
 OchushaBulletinBoard *virtual_board_new(const gchar *name, const char *id,
 					OchushaApplication *application);
 gboolean virtual_board_remove_thread(VirtualBoard *board,
