@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha.h,v 1.17.2.5 2004/12/30 14:15:50 fuyu Exp $
+ * $Id: ochusha.h,v 1.17.2.7 2005/09/06 10:37:59 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_H_
@@ -50,7 +50,8 @@ extern "C" {
  * ʲ2ch˰¸ƤΤǡ̤ξΤ˾
  * 櫡ġ
  */
-#define OCHUSHA_DEFAULT_BBSMENU_URL	"http://www.ff.iij4u.or.jp/~ch2/bbsmenu.html"
+#define OCHUSHA_DEFAULT_BBSMENU_URL_OLD	"http://www.ff.iij4u.or.jp/~ch2/bbsmenu.html"
+#define OCHUSHA_DEFAULT_BBSMENU_URL	"http://menu.2ch.net/bbsmenu.html"
 #define OCHUSHA_SUBJECT_TXT		"subject.txt"
 #define OCHUSHA_SUBBACK_HTML		"subback.html"
 
@@ -74,6 +75,19 @@ extern "C" {
 typedef struct _OchushaConfig OchushaConfig;
 
 
+#define POST_USE_2CH_BE_DEFAULT		0
+#define POST_USE_2CH_BE_YES		1
+#define POST_USE_2CH_BE_NO		2
+#define POST_USE_2CH_BE_MASK		3
+#define POST_MODE_2CH_BE(flags)		(flags & POST_USE_2CH_BE_MASK)
+
+#define POST_USE_2CH_VIEWER_DEFAULT	(0 << 2)
+#define POST_USE_2CH_VIEWER_YES		(1 << 2)
+#define POST_USE_2CH_VIEWER_NO		(2 << 2)
+#define POST_USE_2CH_VIEWER_MASK	(3 << 2)
+#define POST_MODE_2CH_VIEWER(flags)	(flags & POST_USE_2CH_VIEWER_MASK)
+
+
 /*
  * Ū˴ؤΤɤ
  */
@@ -90,10 +104,12 @@ struct _OchushaConfig
   gboolean login_2ch;
   char *session_id_2ch;
 
+  gboolean use_2ch_viewer_for_posting;
+
   char *login_2ch_be_url;
   char *session_id_2ch_be;
 
-  gboolean use_2ch_be_id_for_2ch;
+  gboolean use_2ch_be_id_for_posting;
 
 
   /* proxyϢ */
