@@ -23,12 +23,14 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_async_buffer.h,v 1.13 2004/01/20 13:52:37 fuyu Exp $
+ * $Id: ochusha_async_buffer.h,v 1.14.2.2 2004/06/11 12:00:48 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_ASYNCBUF_H_
 #define _OCHUSHA_ASYNCBUF_H_
 
+#include "monitor.h"
+
 #include <glib-object.h>
 #include <glib.h>
 
@@ -52,8 +54,6 @@ extern "C" {
 typedef struct _OchushaAsyncBuffer OchushaAsyncBuffer;
 typedef struct _OchushaAsyncBufferClass OchushaAsyncBufferClass;
 
-typedef struct _BufferSyncObject BufferSyncObject;
-typedef void SyncFunc(BufferSyncObject *sync_object);
 typedef void DestructFunc(OchushaAsyncBuffer *buffer);
 
 typedef enum
@@ -78,7 +78,7 @@ struct _OchushaAsyncBuffer
   volatile int number_of_suspended_users;
   volatile OchushaAsyncBufferStatus state;
 
-  BufferSyncObject *sync_object;
+  Monitor *monitor;
   DestructFunc *destructor;
 
   volatile unsigned int number_of_lock_waiters;
@@ -104,7 +104,7 @@ struct _OchushaAsyncBufferClass
 };
 
 
-GType ochusha_async_buffer_get_type(void);
+GType ochusha_async_buffer_get_type(void) G_GNUC_CONST;
 
 OchushaAsyncBuffer *ochusha_async_buffer_new(char *buffer, size_t length,
 					     DestructFunc *destructor);
@@ -148,6 +148,15 @@ gboolean ochusha_async_buffer_is_busy(OchushaAsyncBuffer *buffer);
 
 void ochusha_async_buffer_free_when_finished(OchushaAsyncBuffer *buffer);
 
+void ochusha_async_buffer_emit_access_started(OchushaAsyncBuffer *buffer);
+void ochusha_async_buffer_emit_access_progressed(OchushaAsyncBuffer *buffer,
+						 int bytes_read,
+						 int bytes_total);
+void ochusha_async_buffer_emit_access_finished(OchushaAsyncBuffer *buffer);
+void ochusha_async_buffer_emit_access_failed(OchushaAsyncBuffer *buffer,
+					     int reason_code,
+					     const gchar *reason);
+
 
 #ifdef __cplusplus
 } // extern "C"
