@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_table.c,v 1.27.2.7 2004/06/08 15:32:14 fuyu Exp $
+ * $Id: ochusha_bbs_table.c,v 1.27.2.8 2004/11/24 00:00:50 fuyu Exp $
  */
 
 #include "config.h"
@@ -976,6 +976,7 @@ endElementHandler(void *context, const xmlChar *name)
 			case OCHUSHA_BBS_TYPE_2CH_COMPATIBLE:
 			case OCHUSHA_BBS_TYPE_2CH_HEADLINE:
 			case OCHUSHA_BBS_TYPE_2CHLIKE_EUCJP:
+			case OCHUSHA_BBS_TYPE_2CH_BE:
 			  board = ochusha_board_2ch_new(board_name, base_url);
 			  break;
 
@@ -995,9 +996,13 @@ endElementHandler(void *context, const xmlChar *name)
 
 	      if (board != NULL)
 		{
-		  if (bbs_type == OCHUSHA_BBS_TYPE_2CH
-		      && strstr(base_url, "headline.2ch.net") != NULL)
-		    bbs_type = OCHUSHA_BBS_TYPE_2CH_HEADLINE;
+		  if (bbs_type == OCHUSHA_BBS_TYPE_2CH)
+		    {
+		      if (strstr(base_url, "headline.2ch.net") != NULL)
+			bbs_type = OCHUSHA_BBS_TYPE_2CH_HEADLINE;
+		      else if (strstr(base_url, "be.2ch.net") != NULL)
+			bbs_type = OCHUSHA_BBS_TYPE_2CH_BE;
+		    }
 		  ochusha_bulletin_board_set_bbs_type(board, bbs_type);
 #if DEBUG_SAX_HANDLER
 		  fprintf(stderr, "adding board: %s\n", board_name);
