@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_thread.c,v 1.29 2004/02/27 22:16:20 fuyu Exp $
+ * $Id: ochusha_bbs_thread.c,v 1.30.2.1 2005/08/15 17:15:07 fuyu Exp $
  */
 
 #include "config.h"
@@ -60,7 +60,7 @@ static void ochusha_bbs_thread_read_threadlist_element(
 						GHashTable *thread_attributes);
 static void ochusha_bbs_thread_write_threadlist_element(
 						OchushaBBSThread *thread,
-						gzFile *threadlist_xml);
+						gzFile threadlist_xml);
 
 GType
 ochusha_bbs_thread_get_type(void)
@@ -199,6 +199,7 @@ ochusha_bbs_thread_init(OchushaBBSThread *thread)
   thread->number_of_responses_read = 0;
 
   thread->flags = 0;
+  thread->post_mode = 0;
 }
 
 
@@ -588,8 +589,7 @@ ochusha_bbs_thread_is_post_supported(OchushaBBSThread *thread)
 gboolean
 ochusha_bbs_thread_post_response(OchushaBBSThread *thread,
 				 OchushaNetworkBroker *broker,
-				 const OchushaBBSResponse *response,
-				 gboolean use_id)
+				 const OchushaBBSResponse *response)
 {
   OchushaBBSThreadClass *klass;
 
@@ -601,7 +601,7 @@ ochusha_bbs_thread_post_response(OchushaBBSThread *thread,
 
   g_return_val_if_fail(klass->post_response != NULL, FALSE);
 
-  return (*klass->post_response)(thread, broker, response, use_id);
+  return (*klass->post_response)(thread, broker, response);
 }
 
 
@@ -692,6 +692,8 @@ ochusha_bbs_thread_read_threadlist_element(OchushaBBSThread *thread,
     thread->flags &= ~OCHUSHA_BBS_THREAD_STOPPED;
   thread->flags = ochusha_utils_get_attribute_int(thread_attributes,
 						  "flags");
+  thread->post_mode = ochusha_utils_get_attribute_int(thread_attributes,
+						      "post_mode");
 }
 
 
@@ -742,11 +744,89 @@ ochusha_bbs_thread_read_threadlist_element(OchushaBBSThread *thread,
 
 static void
 ochusha_bbs_thread_write_threadlist_element(OchushaBBSThread *thread,
-					    gzFile *threadlist_xml)
+					    gzFile threadlist_xml)
 {
   OUTPUT_THREAD_ATTRIBUTE_STRING(threadlist_xml, thread, id);
   OUTPUT_THREAD_ATTRIBUTE_STRING(threadlist_xml, thread, title);
   OUTPUT_THREAD_ATTRIBUTE_INT(threadlist_xml, thread,
 			      number_of_responses_read);
   OUTPUT_THREAD_ATTRIBUTE_INT(threadlist_xml, thread, flags);
+  OUTPUT_THREAD_ATTRIBUTE_INT(threadlist_xml, thread, post_mode);
+}
+
+
+
+
+gboolean
+ochusha_bbs_thread_get_post_use_2ch_be(OchushaBBSThread *thread,
+				       const OchushaConfig *config)
+{
+  int mode;
+  g_return_val_if_fail(OCHUSHA_IS_BBS_THREAD(thread), FALSE);
+
+  if (thread->board->bbs_type != OCHUSHA_BBS_TYPE_2CH
+      && thread->board->bbs_type != OCHUSHA_BBS_TYPE_2CH_BE)
+    return FALSE;
+
+  mode = POST_MODE_2CH_BE(thread->post_mode);
+  return mode == POST_USE_2CH_BE_YES
+    || (mode == POST_USE_2CH_BE_DEFAULT
+	&& ochusha_bulletin_board_get_post_use_2ch_be(thread->board, config));
+}
+
+
+void
+ochusha_bbs_thread_set_post_use_2ch_be(OchushaBBSThread *thread,
+				       gboolean use_2ch_be)
+{
+  g_return_if_fail(OCHUSHA_IS_BBS_THREAD(thread));
+
+  thread->post_mode &= ~POST_USE_2CH_BE_MASK;
+
+  if (thread->board->bbs_type != OCHUSHA_BBS_TYPE_2CH
+      && thread->board->bbs_type != OCHUSHA_BBS_TYPE_2CH_BE)
+    return;
+
+  if (use_2ch_be)
+    thread->post_mode |= POST_USE_2CH_BE_YES;
+  else
+    thread->post_mode |= POST_USE_2CH_BE_NO;
+}
+
+
+gboolean
+ochusha_bbs_thread_get_post_use_2ch_viewer(OchushaBBSThread *thread,
+					   const OchushaConfig *config)
+{
+  int mode;
+  g_return_val_if_fail(OCHUSHA_IS_BBS_THREAD(thread), FALSE);
+
+  if (thread->board->bbs_type != OCHUSHA_BBS_TYPE_2CH
+      && thread->board->bbs_type != OCHUSHA_BBS_TYPE_2CH_BE)
+    return FALSE;
+
+  mode = POST_MODE_2CH_VIEWER(thread->post_mode);
+  return mode == POST_USE_2CH_VIEWER_YES
+    || (mode == POST_USE_2CH_VIEWER_DEFAULT
+	&& ochusha_bulletin_board_get_post_use_2ch_viewer(thread->board,
+							  config));
+}
+
+
+void
+ochusha_bbs_thread_set_post_use_2ch_viewer(OchushaBBSThread *thread,
+					   gboolean use_2ch_viewer)
+{
+  g_return_if_fail(OCHUSHA_IS_BBS_THREAD(thread));
+
+  thread->post_mode &= ~POST_USE_2CH_VIEWER_MASK;
+
+  if (thread->board->bbs_type != OCHUSHA_BBS_TYPE_2CH
+      && thread->board->bbs_type != OCHUSHA_BBS_TYPE_2CH_BE)
+    return;
+
+  if (use_2ch_viewer)
+    thread->post_mode |= POST_USE_2CH_VIEWER_YES;
+  else
+    thread->post_mode |= POST_USE_2CH_VIEWER_NO;
 }
