@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_thread.h,v 1.25.2.1 2004/06/11 12:00:48 fuyu Exp $
+ * $Id: ochusha_bbs_thread.h,v 1.25.2.2 2005/08/15 17:15:07 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_BBS_THREAD_H_
@@ -75,6 +75,9 @@ struct _OchushaBBSThread
 
   /* Ĥ˴ؤäȤ(OchushaBBSThreadStateORȤä) */
   int flags;
+
+  /* 񤭹ߥե饰(BeȤɤʤ) */
+  int post_mode;
 };
 
 
@@ -134,8 +137,7 @@ struct _OchushaBBSThreadClass
   gboolean (*post_supported)(OchushaBBSThread *thread);
   gboolean (*post_response)(OchushaBBSThread *thread,
 			    OchushaNetworkBroker *broker,
-			    const OchushaBBSResponse *response,
-			    gboolean use_id);
+			    const OchushaBBSResponse *response);
 };
 
 
@@ -220,8 +222,17 @@ gboolean ochusha_bbs_thread_preview_response(OchushaBBSThread *thread,
 
 gboolean ochusha_bbs_thread_post_response(OchushaBBSThread *thread,
 					  OchushaNetworkBroker *broker,
-					  const OchushaBBSResponse *response,
-					  gboolean use_id);
+					  const OchushaBBSResponse *response);
+
+gboolean ochusha_bbs_thread_get_post_use_2ch_be(OchushaBBSThread *thread,
+						const OchushaConfig *config);
+void ochusha_bbs_thread_set_post_use_2ch_be(OchushaBBSThread *thread,
+					    gboolean use_2ch_be);
+gboolean ochusha_bbs_thread_get_post_use_2ch_viewer(OchushaBBSThread *thread,
+						const OchushaConfig *config);
+void ochusha_bbs_thread_set_post_use_2ch_viewer(OchushaBBSThread *thread,
+						gboolean use_2ch_viewer);
+
 
 #ifdef __cplusplus
 } // extern "C"
