@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_2ch.c,v 1.45.2.8 2005/06/10 12:54:01 fuyu Exp $
+ * $Id: ochusha_board_2ch.c,v 1.45.2.10 2005/08/20 15:01:15 fuyu Exp $
  */
 
 #include "config.h"
@@ -115,8 +115,8 @@ static gboolean ochusha_board_2ch_create_new_thread(
 					OchushaBulletinBoard *board,
 					OchushaNetworkBroker *broker,
 					const gchar *title,
-					const OchushaBBSResponse *response,
-					gboolean use_id);
+					const OchushaBBSResponse *response);
+
 
 GType
 ochusha_board_2ch_get_type(void)
@@ -271,7 +271,7 @@ ochusha_board_2ch_read_boardlist_element(OchushaBulletinBoard *board,
 
   board_2ch->last_modified
     = ochusha_utils_get_attribute_string(board_attributes, "last_modified");
-#if 0
+#if 1
   board_2ch->cookie
     = ochusha_utils_get_attribute_string(board_attributes, "cookie");
 #endif
@@ -351,7 +351,7 @@ ochusha_board_2ch_write_boardlist_element(OchushaBulletinBoard *board,
     }
 
   OUTPUT_BOARD_ATTRIBUTE_STRING(boardlist_xml, board_2ch, last_modified);
-#if 0
+#if 1
   OUTPUT_BOARD_ATTRIBUTE_STRING(boardlist_xml, board_2ch, cookie);
 #endif
 }
@@ -751,8 +751,7 @@ static gboolean
 ochusha_board_2ch_create_new_thread(OchushaBulletinBoard *board,
 				    OchushaNetworkBroker *broker,
 				    const gchar *title_utf8,
-				    const OchushaBBSResponse *response,
-				    gboolean use_id)
+				    const OchushaBBSResponse *response)
 {
   OchushaBoard2ch *board_2ch;
   char *tmp_string = NULL;
@@ -842,7 +841,8 @@ ochusha_board_2ch_create_new_thread(OchushaBulletinBoard *board,
   switch (board->bbs_type)
     {
     case OCHUSHA_BBS_TYPE_2CH:
-      if (use_id && broker->config->login_2ch)
+      if (ochusha_bulletin_board_get_post_use_2ch_viewer(board, broker->config)
+	  && broker->config->login_2ch)
 	query = g_strdup_printf("submit=%%90%%56%%8B%%4B%%83%%58%%83%%8C%%83%%62%%83%%68%%8D%%EC%%90%%AC&subject=%s&FROM=%s&mail=%s&MESSAGE=%s&bbs=%s&sid=%s&time=%ld", title, from, mail, message, bbs, broker->config->session_id_2ch, time);
       else
 	query = g_strdup_printf("submit=%%90%%56%%8B%%4B%%83%%58%%83%%8C%%83%%62%%83%%68%%8D%%EC%%90%%AC&subject=%s&FROM=%s&mail=%s&MESSAGE=%s&bbs=%s&time=%ld", title, from, mail, message, bbs, time);
@@ -857,11 +857,12 @@ ochusha_board_2ch_create_new_thread(OchushaBulletinBoard *board,
       goto error_exit;
     }
 
-  post_result = ochusha_utils_2ch_try_post(broker, board, query, NULL);
+  post_result = ochusha_utils_2ch_try_post(broker, board, NULL, query, NULL);
   if (post_result == OCHUSHA_UTILS_2CH_POST_NO_COOKIE)
     {
-      sleep(10);
-      post_result = ochusha_utils_2ch_try_post(broker, board, query, NULL);
+      sleep(30);
+      post_result = ochusha_utils_2ch_try_post(broker, board, NULL,
+					       query, NULL);
     }
 
 #if 0
@@ -869,7 +870,8 @@ ochusha_board_2ch_create_new_thread(OchushaBulletinBoard *board,
     {
       /* XXX: äݤΤȤͭʤΤ֡ */
       sleep(30);
-      post_result = ochusha_utils_2ch_try_post(broker, board, query, NULL);
+      post_result = ochusha_utils_2ch_try_post(broker, board, NULL,
+					       query, NULL);
     }
 #endif
   if (post_result != OCHUSHA_UTILS_2CH_POST_SUCCESS)
