@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_2ch.h,v 1.7 2004/04/05 12:03:15 fuyu Exp $
+ * $Id: ochusha_board_2ch.h,v 1.7.2.1 2004/06/11 12:00:48 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_BOARD_2CH_H_
@@ -74,7 +74,7 @@ struct _OchushaBoard2chClass
 };
 
 
-GType ochusha_board_2ch_get_type(void);
+GType ochusha_board_2ch_get_type(void) G_GNUC_CONST;
 OchushaBulletinBoard *ochusha_board_2ch_new(const gchar *name,
 					    const gchar *url);
 
