@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_category.h,v 1.6 2004/04/13 15:38:05 fuyu Exp $
+ * $Id: ochusha_board_category.h,v 1.6.2.1 2004/06/11 12:00:48 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_BOARD_CATEGORY_H_
@@ -76,7 +76,7 @@ struct _OchushaBoardCategoryClass
 };
 
 
-GType ochusha_board_category_get_type(void);
+GType ochusha_board_category_get_type(void) G_GNUC_CONST;
 OchushaBoardCategory *ochusha_board_category_new(const gchar *name);
 
 void ochusha_board_category_set_name(OchushaBoardCategory *category,
