@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_jbbs.c,v 1.17.2.5 2004/11/25 08:59:45 fuyu Exp $
+ * $Id: ochusha_board_jbbs.c,v 1.17.2.6 2005/08/15 17:15:07 fuyu Exp $
  */
 
 #include "config.h"
@@ -100,8 +100,7 @@ static gboolean ochusha_board_jbbs_create_new_thread(
 					OchushaBulletinBoard *board,
 					OchushaNetworkBroker *broker,
 					const gchar *title,
-					const OchushaBBSResponse *response,
-					gboolean use_id);
+					const OchushaBBSResponse *response);
 
 
 GType
@@ -423,8 +422,7 @@ static gboolean
 ochusha_board_jbbs_create_new_thread(OchushaBulletinBoard *board,
 				     OchushaNetworkBroker *broker,
 				     const gchar *title_utf8,
-				     const OchushaBBSResponse *response,
-				     gboolean use_id)
+				     const OchushaBBSResponse *response)
 {
 #if 0	/* Ǥ̤ݡ */
   OchushaBoard2ch *board_2ch;
@@ -522,11 +520,11 @@ ochusha_board_jbbs_create_new_thread(OchushaBulletinBoard *board,
       goto error_exit;
     }
 
-  post_result = ochusha_utils_2ch_try_post(broker, board, query);
+  post_result = ochusha_utils_2ch_try_post(broker, board, NULL, query, NULL);
   if (post_result == OCHUSHA_UTILS_2CH_POST_NO_COOKIE)
     {
       sleep(10);
-      post_result = ochusha_utils_2ch_try_post(broker, board, query);
+      post_result = ochusha_utils_2ch_try_post(broker, board, NULL, query, NULL);
     }
 
 #if 0
@@ -534,7 +532,7 @@ ochusha_board_jbbs_create_new_thread(OchushaBulletinBoard *board,
     {
       /* XXX: äݤΤȤͭʤΤ֡ */
       sleep(30);
-      post_result = ochusha_utils_2ch_try_post(broker, board, query);
+      post_result = ochusha_utils_2ch_try_post(broker, board, NULL, query, NULL);
     }
 #endif
   if (post_result != OCHUSHA_UTILS_2CH_POST_SUCCESS)
