@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bulletin_board.c,v 1.37.2.1 2004/05/05 12:29:46 fuyu Exp $
+ * $Id: ochusha_bulletin_board.c,v 1.37.2.7 2005/08/15 17:15:07 fuyu Exp $
  */
 
 #include "config.h"
@@ -39,6 +39,7 @@
 #include <libxml/SAX.h>
 #include <libxml/parser.h>
 
+#include <errno.h>
 #include <fcntl.h>
 
 #include <pthread.h>
@@ -46,6 +47,10 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+
+#include <sys/types.h>
+#include <sys/stat.h>
+
 #include <unistd.h>
 
 #include <zlib.h>
@@ -230,16 +235,7 @@ ochusha_bulletin_board_init(OchushaBulletinBoard *board)
 
   board->bbs_type = OCHUSHA_BBS_TYPE_UNKNOWN;
 
-  if (pthread_mutex_init(&board->thread_list_lock, NULL) != 0)
-    {
-      fprintf(stderr, "Couldn't initialize a mutex.\n");
-      abort();
-    }
-  if (pthread_cond_init(&board->thread_list_cond, NULL) != 0)
-    {
-      fprintf(stderr, "Couldn't initialize a condvar.\n");
-      abort();
-    }
+  board->monitor = ochusha_monitor_new(NULL);
 }
 
 
@@ -299,15 +295,10 @@ ochusha_bulletin_board_finalize(GObject *object)
       board->dropped_list = NULL;
     }
 
-  if (pthread_mutex_destroy(&board->thread_list_lock) != 0)
+  if (board->monitor != NULL)
     {
-      fprintf(stderr, "Couldn't destroy a mutex.\n");
-      abort();
-    }
-  if (pthread_cond_destroy(&board->thread_list_cond) != 0)
-    {
-      fprintf(stderr, "Couldn't destroy a condvar.\n");
-      abort();
+      ochusha_monitor_free(board->monitor);
+      board->monitor = NULL;
     }
 
   if (G_OBJECT_CLASS(parent_class)->finalize)
@@ -444,6 +435,88 @@ ochusha_bulletin_board_set_base_url(OchushaBulletinBoard *board,
 }
 
 
+void
+ochusha_bulletin_board_process_board_move(OchushaBulletinBoard *board,
+					  const char *new_url,
+					  OchushaConfig *config)
+{
+  char *old_base_url = G_STRDUP(board->base_url);
+  char *old_path = NULL;
+  char *new_path = NULL;
+  char tmp_path[PATH_MAX];
+  char *tmp_pos;
+  struct stat sb;
+
+  /* åǥ쥯ȥΰư */
+  /* 0.5ϤǤϤad-hocˤ롣*/
+  snprintf(tmp_path, PATH_MAX, "cache/%s%s%s/" OCHUSHA_THREADLIST_XML,
+	   ochusha_bulletin_board_get_server(board),
+	   ochusha_bulletin_board_get_base_path(board),
+	   ochusha_bulletin_board_get_id(board));
+  old_path = ochusha_config_find_file(config, tmp_path, NULL);
+
+  ochusha_bulletin_board_set_base_url(board, new_url);
+
+  snprintf(tmp_path, PATH_MAX, "cache/%s%s%s/" OCHUSHA_THREADLIST_XML,
+	   ochusha_bulletin_board_get_server(board),
+	   ochusha_bulletin_board_get_base_path(board),
+	   ochusha_bulletin_board_get_id(board));
+  new_path = ochusha_config_find_file(config, tmp_path, NULL);
+
+  if (new_path == NULL && old_path != NULL)
+    {
+      snprintf(tmp_path, PATH_MAX, "%s/cache/%s%s%s/" OCHUSHA_THREADLIST_XML,
+	       config->home,
+	       ochusha_bulletin_board_get_server(board),
+	       ochusha_bulletin_board_get_base_path(board),
+	       ochusha_bulletin_board_get_id(board));
+      tmp_pos = strstr(tmp_path, "/threadlist.xml");
+      *tmp_pos = '\0';
+      if (mkdir_p(tmp_path))
+	{
+	  *tmp_pos = '/';
+	  rename(old_path, tmp_path);
+#if 0
+	  fprintf(stderr, "%s is moved to %s\n", old_path, tmp_path);
+#endif
+	}
+      new_path = G_STRDUP(tmp_path);
+    }
+
+  if (old_path != NULL)
+    {
+      tmp_pos = strstr(old_path, "/threadlist.xml");
+      tmp_pos[1] = 'd';
+      tmp_pos[2] = 'a';
+      tmp_pos[3] = 't';
+      tmp_pos[4] = '\0';
+      if (stat(old_path, &sb) == 0)
+	{
+	  tmp_pos = strstr(new_path, "/threadlist.xml");
+	  tmp_pos[1] = 'd';
+	  tmp_pos[2] = 'a';
+	  tmp_pos[3] = 't';
+	  tmp_pos[4] = '\0';
+	  if (stat(new_path, &sb) != 0 && errno == ENOENT)
+	    {
+	      rename(old_path, new_path);
+#if 0
+	      fprintf(stderr, "%s is moved to %s\n", old_path, new_path);
+#endif
+	    }
+	}
+    }
+
+  if (old_path != NULL)
+    G_FREE(old_path);
+
+  if (new_path != NULL)
+    G_FREE(new_path);
+
+  G_FREE(old_base_url);
+}
+
+
 void
 ochusha_bulletin_board_set_bbs_type(OchushaBulletinBoard *board,
 				    int bbs_type)
@@ -542,22 +615,7 @@ ochusha_bulletin_board_lock_thread_list(OchushaBulletinBoard *board)
 {
   g_assert(OCHUSHA_IS_BULLETIN_BOARD(board));
 
-  if (pthread_mutex_lock(&board->thread_list_lock) != 0)
-    {
-      fprintf(stderr, "Couldn't lock a mutex.\n");
-      abort();
-    }
-  while (board->is_busy)
-    {
-      fprintf(stderr, "board->is_busy.\n");
-      if (pthread_cond_wait(&board->thread_list_cond,
-			    &board->thread_list_lock) != 0)
-	{
-	  fprintf(stderr, "Couldn't wait a condition.\n");
-	  abort();
-	}
-    }
-  board->is_busy = TRUE;
+  ochusha_monitor_enter(board->monitor);
 }
 
 
@@ -566,21 +624,7 @@ ochusha_bulletin_board_trylock_thread_list(OchushaBulletinBoard *board)
 {
   g_assert(OCHUSHA_IS_BULLETIN_BOARD(board));
 
-  if (pthread_mutex_trylock(&board->thread_list_lock) != 0)
-    return FALSE;
-
-  if (board->is_busy)
-    {
-      if (pthread_mutex_unlock(&board->thread_list_lock) != 0)
-	{
-	  fprintf(stderr, "Couldn't unlock a mutex.\n");
-	  abort();
-	}
-      return FALSE;
-    }
-
-  board->is_busy = TRUE;
-  return TRUE;
+  return ochusha_monitor_try_enter(board->monitor);
 }
 
 
@@ -588,19 +632,8 @@ void
 ochusha_bulletin_board_unlock_thread_list(OchushaBulletinBoard *board)
 {
   g_assert(OCHUSHA_IS_BULLETIN_BOARD(board));
-  g_assert(board->is_busy);	/* ٤åġ */
 
-  board->is_busy = FALSE;
-  if (pthread_cond_signal(&board->thread_list_cond) != 0)
-    {
-      fprintf(stderr, "Couldn't signal a condition.\n");
-      abort();
-    }
-  if (pthread_mutex_unlock(&board->thread_list_lock) != 0)
-    {
-      fprintf(stderr, "Couldn't unlock a mutex.\n");
-      abort();
-    }
+  ochusha_monitor_exit(board->monitor);
 }
 
 
@@ -805,8 +838,7 @@ gboolean
 ochusha_bulletin_board_create_new_thread(OchushaBulletinBoard *board,
 					 OchushaNetworkBroker *broker,
 					 const gchar *title,
-					 const OchushaBBSResponse *response,
-					 gboolean use_id)
+					 const OchushaBBSResponse *response)
 {
   OchushaBulletinBoardClass *klass;
 
@@ -819,7 +851,7 @@ ochusha_bulletin_board_create_new_thread(OchushaBulletinBoard *board,
 
   g_return_val_if_fail(klass->create_new_thread != NULL, FALSE);
 
-  return (*klass->create_new_thread)(board, broker, title, response, use_id);
+  return (*klass->create_new_thread)(board, broker, title, response);
 }
 
 
@@ -874,6 +906,8 @@ ochusha_bulletin_board_read_boardlist_element(OchushaBulletinBoard *board,
 {
   board->hidden = ochusha_utils_get_attribute_boolean(board_attributes,
 						      "hidden");
+  board->post_mode = ochusha_utils_get_attribute_int(board_attributes,
+						     "post_mode");
 }
 
 
@@ -885,6 +919,7 @@ ochusha_bulletin_board_write_boardlist_element(OchushaBulletinBoard *board,
   OUTPUT_BOARD_ATTRIBUTE_STRING(boardlist_xml, board, name);
   OUTPUT_BOARD_ATTRIBUTE_STRING(boardlist_xml, board, base_url);
   OUTPUT_BOARD_ATTRIBUTE_BOOLEAN(boardlist_xml, board, hidden);
+  OUTPUT_BOARD_ATTRIBUTE_INT(boardlist_xml, board, post_mode);
 }
 
 
@@ -1172,7 +1207,7 @@ endElementHandler(void *context, const xmlChar *name)
 					thread,
 					thread_attrs);
 			  board->thread_list
-			    = g_slist_append(board->thread_list, thread);
+			    = g_slist_prepend(board->thread_list, thread);
 			}
 		    }
 		}
@@ -1360,6 +1395,10 @@ write_bbs_thread(gpointer data, gpointer user_data)
   WriteThreadlistArgs *args = (WriteThreadlistArgs *)user_data;
   gzFile threadlist_xml = args->threadlist_xml;
 
+  if (thread->flags & OCHUSHA_BBS_THREAD_DAT_DROPPED
+      && ochusha_bbs_thread_get_number_of_responses_read(thread) == 0)
+    return;
+
   gzprintf(threadlist_xml, "    <thread>\n");
 
   g_signal_emit_by_name(G_OBJECT(thread),
@@ -1449,3 +1488,76 @@ ochusha_bulletin_board_write_threadlist_xml(OchushaBulletinBoard *board,
   return gzclose(threadlist_xml) == 0;
 }
 
+
+gboolean
+ochusha_bulletin_board_get_post_use_2ch_be(OchushaBulletinBoard *board,
+					   const OchushaConfig *config)
+{
+  int mode;
+  g_return_val_if_fail(OCHUSHA_IS_BULLETIN_BOARD(board), FALSE);
+
+  if (board->bbs_type != OCHUSHA_BBS_TYPE_2CH
+      && board->bbs_type != OCHUSHA_BBS_TYPE_2CH_BE)
+    return FALSE;
+
+  mode = POST_MODE_2CH_BE(board->post_mode);
+  return mode == POST_USE_2CH_BE_YES
+    || (mode == POST_USE_2CH_BE_DEFAULT && config->use_2ch_be_id_for_posting);
+}
+
+
+void
+ochusha_bulletin_board_set_post_use_2ch_be(OchushaBulletinBoard *board,
+					   gboolean use_2ch_be)
+{
+  g_return_if_fail(OCHUSHA_IS_BULLETIN_BOARD(board));
+
+  board->post_mode &= ~POST_USE_2CH_BE_MASK;
+
+  if (board->bbs_type != OCHUSHA_BBS_TYPE_2CH
+      && board->bbs_type != OCHUSHA_BBS_TYPE_2CH_BE)
+    return;
+
+  if (use_2ch_be)
+    board->post_mode |= POST_USE_2CH_BE_YES;
+  else
+    board->post_mode |= POST_USE_2CH_BE_NO;
+}
+
+
+gboolean
+ochusha_bulletin_board_get_post_use_2ch_viewer(OchushaBulletinBoard *board,
+					       const OchushaConfig *config)
+{
+  int mode;
+  g_return_val_if_fail(OCHUSHA_IS_BULLETIN_BOARD(board), FALSE);
+
+  if (board->bbs_type != OCHUSHA_BBS_TYPE_2CH
+      && board->bbs_type != OCHUSHA_BBS_TYPE_2CH_BE)
+    return FALSE;
+
+  mode = POST_MODE_2CH_VIEWER(board->post_mode);
+  return mode == POST_USE_2CH_VIEWER_YES
+    || (mode == POST_USE_2CH_VIEWER_DEFAULT
+	&& config->use_2ch_viewer_for_posting);
+}
+
+
+void
+ochusha_bulletin_board_set_post_use_2ch_viewer(OchushaBulletinBoard *board,
+					       gboolean use_2ch_viewer)
+{
+  g_return_if_fail(OCHUSHA_IS_BULLETIN_BOARD(board));
+
+  board->post_mode &= ~POST_USE_2CH_VIEWER_MASK;
+
+  if (board->bbs_type != OCHUSHA_BBS_TYPE_2CH
+      && board->bbs_type != OCHUSHA_BBS_TYPE_2CH_BE)
+    return;
+
+  if (use_2ch_viewer)
+    board->post_mode |= POST_USE_2CH_VIEWER_YES;
+  else
+    board->post_mode |= POST_USE_2CH_VIEWER_NO;
+}
+
