@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bulletin_board.h,v 1.27.2.4 2004/11/24 00:00:50 fuyu Exp $
+ * $Id: ochusha_bulletin_board.h,v 1.27.2.5 2005/08/15 17:15:07 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_BULLETIN_BOARD_H_
@@ -99,6 +99,9 @@ struct _OchushaBulletinBoard
   gboolean hidden;		/* İ鱣 */
   gboolean killed;		/* İ¸˼ΤƤ */
 
+  /* 񤭹ߥե饰(BeȤɤʤ) */
+  int post_mode;
+
   Monitor *monitor;
 };
 
@@ -160,8 +163,7 @@ struct _OchushaBulletinBoardClass
   gboolean (*create_new_thread)(OchushaBulletinBoard *board,
 				OchushaNetworkBroker *broker,
 				const gchar *title,
-				const OchushaBBSResponse *response,
-				gboolean use_id);
+				const OchushaBBSResponse *response);
 };
 
 
@@ -241,8 +243,7 @@ gboolean ochusha_bulletin_board_is_new_thread_supported(
 gboolean ochusha_bulletin_board_create_new_thread(OchushaBulletinBoard *board,
 					OchushaNetworkBroker *broker,
 					const gchar *title,
-					const OchushaBBSResponse *response,
-					gboolean use_id);
+					const OchushaBBSResponse *response);
 
 gboolean ochusha_bulletin_board_read_threadlist_xml(
 					OchushaBulletinBoard *board,
@@ -254,6 +255,16 @@ gboolean ochusha_bulletin_board_write_threadlist_xml(
 					OchushaConfig *config,
 					const char *subdir);
 
+gboolean ochusha_bulletin_board_get_post_use_2ch_be(OchushaBulletinBoard *board,
+						const OchushaConfig *config);
+void ochusha_bulletin_board_set_post_use_2ch_be(OchushaBulletinBoard *board,
+						gboolean use_2ch_be);
+gboolean ochusha_bulletin_board_get_post_use_2ch_viewer(OchushaBulletinBoard *board,
+						const OchushaConfig *config);
+void ochusha_bulletin_board_set_post_use_2ch_viewer(OchushaBulletinBoard *board,
+						    gboolean use_2ch_viewer);
+
+
 #ifdef __cplusplus
 } // extern "C"
 #endif
