@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_config.c,v 1.28.2.4 2004/12/30 14:15:50 fuyu Exp $
+ * $Id: ochusha_config.c,v 1.28.2.6 2005/09/06 10:37:59 fuyu Exp $
  */
 
 #include "config.h"
@@ -1069,7 +1069,10 @@ ochusha_write_config_xml(OchushaConfig *config, const char *subdir,
 
   OUTPUT_CONFIG_ATTRIBUTE_STRING(config_xml, config, bbsmenu_url);
   OUTPUT_CONFIG_ATTRIBUTE_STRING(config_xml, config, login_2ch_url);
-  OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(config_xml, config, use_2ch_be_id_for_2ch);
+  OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(config_xml, config,
+				  use_2ch_viewer_for_posting);
+  OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(config_xml, config,
+				  use_2ch_be_id_for_posting);
 
   OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(config_xml, config, offline);
 
@@ -1129,7 +1132,9 @@ ochusha_read_config_xml(OchushaConfig *config, const char *subdir,
     {
       config->bbsmenu_url = G_STRDUP(OCHUSHA_DEFAULT_BBSMENU_URL);
       config->login_2ch_url = G_STRDUP(OCHUSHA_DOLIB_URL);
-      config->use_2ch_be_id_for_2ch = FALSE;
+
+      config->use_2ch_viewer_for_posting = FALSE;
+      config->use_2ch_be_id_for_posting = FALSE;
 
       config->offline = FALSE;
 
@@ -1173,6 +1178,11 @@ ochusha_read_config_xml(OchushaConfig *config, const char *subdir,
 
       config->bbsmenu_url
 	= ochusha_utils_get_attribute_string(pref, "bbsmenu_url");
+      if (strcmp(config->bbsmenu_url, OCHUSHA_DEFAULT_BBSMENU_URL_OLD) == 0)
+	{
+	  G_FREE(config->bbsmenu_url);
+	  config->bbsmenu_url = G_STRDUP(OCHUSHA_DEFAULT_BBSMENU_URL);
+	}
       config->login_2ch_url
 	= ochusha_utils_get_attribute_string(pref, "login_2ch_url");
       if (config->login_2ch_url == NULL)
@@ -1185,8 +1195,13 @@ ochusha_read_config_xml(OchushaConfig *config, const char *subdir,
 	  config->login_2ch_url = G_STRDUP(OCHUSHA_DOLIB_URL);
 	}
 
-      config->use_2ch_be_id_for_2ch
-	= ochusha_utils_get_attribute_boolean(pref, "use_2ch_be_id_for_2ch");
+      config->use_2ch_viewer_for_posting
+	= ochusha_utils_get_attribute_boolean(pref,
+					      "use_2ch_viewer_for_posting");
+      config->use_2ch_be_id_for_posting
+	= ochusha_utils_get_attribute_boolean(pref,
+					      "use_2ch_be_id_for_posting")
+	|| ochusha_utils_get_attribute_boolean(pref, "use_2ch_be_id_for_2ch");
 
       config->offline = ochusha_utils_get_attribute_boolean(pref, "offline");
 
