@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_2ch.c,v 1.71.2.10 2005/08/01 06:07:38 fuyu Exp $
+ * $Id: ochusha_thread_2ch.c,v 1.71.2.13 2005/09/09 13:18:20 fuyu Exp $
  */
 
 #include "config.h"
@@ -123,8 +123,7 @@ static gboolean ochusha_thread_2ch_post_supported(OchushaBBSThread *thread);
 
 static gboolean ochusha_thread_2ch_post_response(OchushaBBSThread *thread,
 					OchushaNetworkBroker *broker,
-					const OchushaBBSResponse *response,
-					gboolean use_id);
+					const OchushaBBSResponse *response);
 
 static char *ochusha_thread_2ch_get_url_for_response(OchushaBBSThread *thread,
 						     int from, int to);
@@ -470,8 +469,18 @@ ochusha_thread_2ch_get_dat_url(OchushaThread2ch *thread_2ch)
   OchushaBBSThread *thread;
   g_return_val_if_fail(OCHUSHA_IS_THREAD_2CH(thread_2ch), NULL);
 
+#if 0
   if (thread_2ch->dat_url != NULL)
     return thread_2ch->dat_url;
+#else
+  /* datեURLΥå᤿call siteľ
+   * ޤΤݤʤΤǡad-hoc˽*/
+  if (thread_2ch->dat_url != NULL)
+    {
+      G_FREE(thread_2ch->dat_url);
+      thread_2ch->dat_url = NULL;
+    }
+#endif
 
   thread = OCHUSHA_BBS_THREAD(thread_2ch);
 
@@ -1321,7 +1330,7 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 
 #if 1
   if (onig_new(&be_pattern,
-	       (char *)be_link_pattern_string, (char *)be_link_pattern_end,
+	       (UChar *)be_link_pattern_string, (UChar *)be_link_pattern_end,
 	       ONIG_OPTION_NONE, ONIG_ENCODING_SJIS,
 	       ONIG_SYNTAX_RUBY, NULL) != ONIG_NORMAL)
     {
@@ -1338,7 +1347,7 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
   if (responses == NULL)
     {
       /*
-       * 1000쥹ʬǤ⡹4000ХȤʤΤǡ
+       * 1000쥹ʬǤ⡹4000Х(32bitĶ)ʤΤǡ
        * ǽ餫MAX_RESPONSE쥹ʬ϶Ȥ롣
        */
       responses = G_MALLOC0(sizeof(unsigned int) * MAX_RESPONSE);
@@ -1458,8 +1467,8 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 			char *date_id_end = date_id + strlen(response.date_id);
 
 			if (onig_search(be_pattern,
-					date_id, date_id_end,
-					date_id, date_id_end,
+					(UChar *)date_id, (UChar *)date_id_end,
+					(UChar *)date_id, (UChar *)date_id_end,
 					match_region, 0) >= 0)
 			  {
 			    /*
@@ -1759,8 +1768,18 @@ ochusha_thread_2ch_get_url_to_post(OchushaBBSThread *thread)
   g_return_val_if_fail(OCHUSHA_IS_THREAD_2CH(thread), NULL);
 
   thread_2ch = OCHUSHA_THREAD_2CH(thread);
+#if 0
   if (thread_2ch->post_url != NULL)
     return thread_2ch->post_url;
+#else
+  /* postURLΥå᤿call siteľƤޤΤ
+   * ݤʤΤǡad-hoc˽*/
+  if (thread_2ch->post_url != NULL)
+    {
+      G_FREE(thread_2ch->post_url);
+      thread_2ch->post_url = NULL;
+    }
+#endif
 
   snprintf(url, PATH_MAX, "%sl10",
 	   ochusha_thread_2ch_get_base_url(thread));
@@ -1795,8 +1814,7 @@ ochusha_thread_2ch_post_supported(OchushaBBSThread *thread)
 static gboolean
 ochusha_thread_2ch_post_response(OchushaBBSThread *thread,
 				 OchushaNetworkBroker *broker,
-				 const OchushaBBSResponse *response,
-				 gboolean use_id)
+				 const OchushaBBSResponse *response)
 {
   OchushaThread2ch *thread_2ch;
   OchushaThread2chClass *thread_2ch_class;
@@ -1861,8 +1879,8 @@ ochusha_thread_2ch_post_response(OchushaBBSThread *thread,
 							    key, time);
   else
     {
-      if (use_id && broker->config->login_2ch
-	  && thread->board->bbs_type == OCHUSHA_BBS_TYPE_2CH)
+      if (ochusha_bbs_thread_get_post_use_2ch_viewer(thread, broker->config)
+	  && broker->config->login_2ch)
 	query = g_strdup_printf("submit=%%8F%%91%%82%%AB%%8D%%9E%%82%%DE&FROM=%s&mail=%s&MESSAGE=%s&bbs=%s&key=%s&sid=%s&time=%ld", from, mail, message, bbs, key, broker->config->session_id_2ch, time);
       else
 	query = g_strdup_printf("submit=%%8F%%91%%82%%AB%%8D%%9E%%82%%DE&FROM=%s&mail=%s&MESSAGE=%s&bbs=%s&key=%s&time=%ld", from, mail, message, bbs, key, time);
@@ -1871,7 +1889,8 @@ ochusha_thread_2ch_post_response(OchushaBBSThread *thread,
   if (query == NULL)
     goto error_exit;
 
-  post_result = ochusha_utils_2ch_try_post(broker, thread->board, query, key);
+  post_result = ochusha_utils_2ch_try_post(broker, thread->board, thread,
+					   query, key);
   if (post_result == OCHUSHA_UTILS_2CH_POST_NO_COOKIE)
     {
       if (ochusha_board_2ch_get_cookie(board_2ch) != NULL)
@@ -1879,14 +1898,16 @@ ochusha_thread_2ch_post_response(OchushaBBSThread *thread,
 	  if (thread->board->bbs_type == OCHUSHA_BBS_TYPE_2CH)
 	    {
 	      g_free(query);
-	      if (use_id && broker->config->login_2ch)
+	      if (ochusha_bbs_thread_get_post_use_2ch_viewer(thread,
+							     broker->config)
+		  && broker->config->login_2ch)
 		query = g_strdup_printf("submit=%%91%%53%%90%%D3%%94%%43%%82%%F0%%95%%89%%82%%A4%%82%%B1%%82%%C6%%82%%F0%%8F%%B3%%91%%F8%%82%%B5%%82%%C4%%8F%%91%%82%%AB%%8D%%9E%%82%%DE&FROM=%s&mail=%s&MESSAGE=%s&bbs=%s&key=%s&sid=%s&time=%ld", from, mail, message, bbs, key, broker->config->session_id_2ch, time);
 	      else
 		query = g_strdup_printf("submit=%%91%%53%%90%%D3%%94%%43%%82%%F0%%95%%89%%82%%A4%%82%%B1%%82%%C6%%82%%F0%%8F%%B3%%91%%F8%%82%%B5%%82%%C4%%8F%%91%%82%%AB%%8D%%9E%%82%%DE&FROM=%s&mail=%s&MESSAGE=%s&bbs=%s&key=%s&time=%ld", from, mail, message, bbs, key, time);
 	    }
 	  sleep(30);
 	  post_result = ochusha_utils_2ch_try_post(broker, thread->board,
-						   query, key);
+						   thread, query, key);
 	}
       else
 	{
@@ -1900,7 +1921,8 @@ ochusha_thread_2ch_post_response(OchushaBBSThread *thread,
       /* XXX: äݤΤȤͭʤΤ֡ */
       sleep(30);
       post_result
-	= ochusha_utils_2ch_try_post(broker, thread->board, query, key);
+	= ochusha_utils_2ch_try_post(broker, thread->board, thread,
+				     query, key);
     }
 #endif
 
