@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_jbbs.c,v 1.38.2.8 2005/08/01 06:07:39 fuyu Exp $
+ * $Id: ochusha_thread_jbbs.c,v 1.38.2.10 2005/09/09 13:18:20 fuyu Exp $
  */
 
 #include "config.h"
@@ -805,8 +805,18 @@ ochusha_thread_jbbs_get_base_url(OchushaBBSThread *thread)
   g_return_val_if_fail(OCHUSHA_IS_THREAD_2CH(thread), NULL);
   thread_2ch = OCHUSHA_THREAD_2CH(thread);
 
+#if 0
   if (thread_2ch->base_url != NULL)
     return thread_2ch->base_url;
+#else
+      /* URLΥå᤿call siteľƤޤΤ
+       * ݤʤΤǡad-hoc˽*/
+  if (thread_2ch->base_url != NULL)
+    {
+      G_FREE(thread_2ch->base_url);
+      thread_2ch->base_url = NULL;
+    }
+#endif
 
   base_path = ochusha_thread_2ch_get_base_path(thread_2ch);
 
@@ -886,8 +896,18 @@ ochusha_thread_jbbs_get_url_to_post(OchushaBBSThread *thread)
   g_return_val_if_fail(OCHUSHA_IS_THREAD_2CH(thread), NULL);
 
   thread_2ch = OCHUSHA_THREAD_2CH(thread);
+#if 0
   if (thread_2ch->post_url != NULL)
     return thread_2ch->post_url;
+#else
+  /* postURLΥå᤿call siteľƤޤΤ
+   * ݤʤΤǡad-hoc˽*/
+  if (thread_2ch->post_url != NULL)
+    {
+      G_FREE(thread_2ch->post_url);
+      thread_2ch->post_url = NULL;
+    }
+#endif
 
   switch (thread->board->bbs_type)
     {
@@ -1083,7 +1103,7 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
     {
     case OCHUSHA_BBS_TYPE_JBBS_SHITARABA:
       if (onig_new(&title_pattern,
-		   (char *)title_pattern_string, (char *)title_pattern_end,
+		   (UChar *)title_pattern_string, (UChar *)title_pattern_end,
 		   ONIG_OPTION_NONE, ONIG_ENCODING_EUC_JP,
 		   ONIG_SYNTAX_RUBY, NULL) != ONIG_NORMAL)
 	{
@@ -1091,8 +1111,8 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
 	  goto terminated;
 	}
       if (onig_new(&response_pattern,
-		   (char *)jbbs_shitaraba_response_pattern_string,
-		   (char *)jbbs_shitaraba_response_pattern_end,
+		   (UChar *)jbbs_shitaraba_response_pattern_string,
+		   (UChar *)jbbs_shitaraba_response_pattern_end,
 		   ONIG_OPTION_NONE, ONIG_ENCODING_EUC_JP,
 		   ONIG_SYNTAX_RUBY, NULL) != ONIG_NORMAL)
 	{
@@ -1108,7 +1128,7 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
 
     case OCHUSHA_BBS_TYPE_MACHIBBS:
       if (onig_new(&title_pattern,
-		   (char *)title_pattern_string, (char *)title_pattern_end,
+		   (UChar *)title_pattern_string, (UChar *)title_pattern_end,
 		   ONIG_OPTION_NONE, ONIG_ENCODING_SJIS,
 		   ONIG_SYNTAX_RUBY, NULL) != ONIG_NORMAL)
 	{
@@ -1116,8 +1136,8 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
 	  goto terminated;
 	}
       if (onig_new(&response_pattern,
-		   (char *)machibbs_response_pattern_string,
-		   (char *)machibbs_response_pattern_end,
+		   (UChar *)machibbs_response_pattern_string,
+		   (UChar *)machibbs_response_pattern_end,
 		   ONIG_OPTION_NONE, ONIG_ENCODING_SJIS,
 		   ONIG_SYNTAX_RUBY, NULL) != ONIG_NORMAL)
 	{
@@ -1133,7 +1153,7 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
 
     case OCHUSHA_BBS_TYPE_MITINOKU:
       if (onig_new(&title_pattern,
-		   (char *)title_pattern_string, (char *)title_pattern_end,
+		   (UChar *)title_pattern_string, (UChar *)title_pattern_end,
 		   ONIG_OPTION_NONE, ONIG_ENCODING_EUC_JP,
 		   ONIG_SYNTAX_RUBY, NULL) != ONIG_NORMAL)
 	{
@@ -1141,8 +1161,8 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
 	  goto terminated;
 	}
       if (onig_new(&response_pattern,
-		   (char *)mitinoku_response_pattern_string,
-		   (char *)mitinoku_response_pattern_end,
+		   (UChar *)mitinoku_response_pattern_string,
+		   (UChar *)mitinoku_response_pattern_end,
 		   ONIG_OPTION_NONE, ONIG_ENCODING_EUC_JP,
 		   ONIG_SYNTAX_RUBY, NULL) != ONIG_NORMAL)
 	{
@@ -1236,8 +1256,10 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
 	  onig_region_clear(match_region);
 	  if (response_number == 1 && title == NULL
 	      && onig_search(title_pattern,
-			     html_line_buffer, html_line_buffer_tail,
-			     html_line_buffer, html_line_buffer_tail,
+			     (UChar *)html_line_buffer,
+			     (UChar *)html_line_buffer_tail,
+			     (UChar *)html_line_buffer,
+			     (UChar *)html_line_buffer_tail,
 			     match_region, 0) >= 0)
 	    {
 	      char *title_head = html_line_buffer + match_region->beg[1];
@@ -1252,8 +1274,10 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
 	      fprintf(stderr, "html_line: \"%s\"\n", html_line_buffer);
 	    }
 	  else if (onig_search(response_pattern,
-			       html_line_buffer, html_line_buffer_tail,
-			       html_line_buffer, html_line_buffer_tail,
+			       (UChar *)html_line_buffer,
+			       (UChar *)html_line_buffer_tail,
+			       (UChar *)html_line_buffer,
+			       (UChar *)html_line_buffer_tail,
 			       match_region, 0) >= 0)
 	    {
 	      int res_num;
