@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_jbbs.h,v 1.2 2004/01/15 02:12:14 fuyu Exp $
+ * $Id: ochusha_thread_jbbs.h,v 1.2.2.1 2004/06/11 12:00:48 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_THREAD_JBBS_H_
@@ -64,7 +64,7 @@ struct _OchushaThreadJBBSClass
 };
 
 
-GType ochusha_thread_jbbs_get_type(void);
+GType ochusha_thread_jbbs_get_type(void) G_GNUC_CONST;
 OchushaBBSThread *ochusha_thread_jbbs_new(OchushaBoardJBBS *board,
 					  const char *thread_id,
 					  const gchar *title);
