@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_utils_2ch.c,v 1.40.2.15 2005/06/06 18:59:22 fuyu Exp $
+ * $Id: ochusha_utils_2ch.c,v 1.40.2.17 2005/09/09 13:18:20 fuyu Exp $
  */
 
 #include "config.h"
@@ -31,8 +31,10 @@
 #include "ochusha_private.h"
 #include "ochusha.h"
 #include "ochusha_bbs_table.h"
+#include "ochusha_bulletin_board.h"
 #include "ochusha_board_2ch.h"
 #include "ochusha_board_jbbs.h"
+#include "ochusha_bbs_thread.h"
 #include "ochusha_thread_2ch.h"
 #include "ochusha_utils_2ch.h"
 
@@ -290,8 +292,8 @@ ochusha_utils_2ch_check_url(const char *url, char **board_url_p,
   int bbs_type = OCHUSHA_BBS_TYPE_UNKNOWN;
   char *thread_id = NULL;
   char *board_id = NULL;
-  int from = 0;
-  int to = 0;
+  unsigned int from = 0;
+  unsigned int to = 0;
   char board_url[PATH_MAX];
   char tmp_buf[PATH_MAX];
 
@@ -1043,6 +1045,7 @@ ochusha_utils_2ch_analyze_bbsmenu(OchushaBBSTable *table,
 OchushaUtils2chPostResult
 ochusha_utils_2ch_try_post(OchushaNetworkBroker *broker,
 			   OchushaBulletinBoard *board,
+			   OchushaBBSThread *thread,
 			   const char *message, const char *key)
 {
   char url[PATH_MAX];
@@ -1105,12 +1108,18 @@ ochusha_utils_2ch_try_post(OchushaNetworkBroker *broker,
       cookie = cookie_buf;
     }
   else if (board->bbs_type == OCHUSHA_BBS_TYPE_2CH
-	   && cookie != NULL
-	   && broker->config->use_2ch_be_id_for_2ch
+	   && (thread != NULL
+	       ? ochusha_bbs_thread_get_post_use_2ch_be(thread,
+							broker->config)
+	       : ochusha_bulletin_board_get_post_use_2ch_be(board,
+							    broker->config))
 	   && broker->config->session_id_2ch_be != NULL)
     {
-      snprintf(cookie_buf, 4096, "%s %s ;",
-	       broker->config->session_id_2ch_be, cookie);
+      if (cookie != NULL)
+	snprintf(cookie_buf, 4096, "%s %s ;",
+		 broker->config->session_id_2ch_be, cookie);
+      else
+	snprintf(cookie_buf, 4096, "%s", broker->config->session_id_2ch_be);
       cookie = cookie_buf;
     }
 #if DEBUG_POST
