@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: utils.h,v 1.13.2.5 2005/06/06 12:47:07 fuyu Exp $
+ * $Id: utils.h,v 1.13.2.6 2005/09/04 06:44:24 fuyu Exp $
  */
 
 #ifndef _UTILS_H_
@@ -60,6 +60,8 @@ gchar *wipe_string(const gchar *string);
 
 char *ochusha_utils_canon_cookie(const char *value);
 char *ochusha_utils_shell_escape_text(const char *text);
+gboolean ochusha_utils_spawn_command_line(const char *command_line,
+					  GError **error);
 
 char *ochusha_utils_url_extract_scheme(const char *url);
 char *ochusha_utils_url_extract_http_server(const char *url);
