@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: worker.c,v 1.5 2004/01/21 17:24:50 fuyu Exp $
+ * $Id: worker.c,v 1.5.2.1 2004/06/26 18:02:59 fuyu Exp $
  */
 
 #include "config.h"
@@ -31,6 +31,7 @@
 #include "ochusha_private.h"
 #include "ochusha.h"
 
+#include "monitor.h"
 #include "worker.h"
 
 #include <glib.h>
@@ -41,79 +42,60 @@
 #include <stdlib.h>
 
 
-static pthread_mutex_t job_list_lock;
-static pthread_cond_t idle_threads;
+static Monitor *normal_job_monitor = NULL;
 static volatile GSList *job_list = NULL;
 static volatile GSList *worker_threads = NULL;
 static int maximum_number_of_worker_threads;
 static volatile int number_of_idle_threads;
 static volatile int number_of_threads;
 
-
 static WorkerThread *worker_thread_new(void);
 static void *worker_thread_main(void *args);
 
 
 
-static pthread_mutex_t modest_job_list_lock;
-static pthread_cond_t idle_modest_threads;
+static Monitor *modest_job_monitor = NULL;
 static volatile GSList *modest_job_list = NULL;
 static volatile GSList *modest_worker_threads = NULL;
 static int maximum_number_of_modest_threads;
 static volatile int number_of_idle_modest_threads;
 static volatile int number_of_modest_threads;
 
-
 static WorkerThread *modest_worker_thread_new(void);
 static void *modest_worker_thread_main(void *args);
 
 
+
+static Monitor *loader_job_monitor = NULL;
+static volatile GSList *loader_job_list = NULL;
+static volatile GSList *loader_worker_threads = NULL;
+static int maximum_number_of_loader_threads;
+static volatile int number_of_idle_loader_threads;
+static volatile int number_of_loader_threads;
+
+static WorkerThread *loader_worker_thread_new(void);
+static void *loader_worker_thread_main(void *args);
+
+
+
+
 static pthread_attr_t worker_thread_attribute;
 
 
 
-
-#define JOB_LIST_LOCK					\
-  if (pthread_mutex_lock(&job_list_lock) != 0)		\
-    {							\
-      fprintf(stderr, "Couldn't lock a mutex.\n");	\
-      abort();						\
-    }
-
-#define JOB_LIST_UNLOCK					\
-  if (pthread_mutex_unlock(&job_list_lock) != 0)	\
-    {							\
-      fprintf(stderr, "Couldn't unlock a mutex.\n");	\
-      abort();						\
-    }
-
-#define MODEST_JOB_LIST_LOCK				\
-  if (pthread_mutex_lock(&modest_job_list_lock) != 0)	\
-    {							\
-      fprintf(stderr, "Couldn't lock a mutex.\n");	\
-      abort();						\
-    }
-
-#define MODEST_JOB_LIST_UNLOCK				\
-  if (pthread_mutex_unlock(&modest_job_list_lock) != 0)	\
-    {							\
-      fprintf(stderr, "Couldn't unlock a mutex.\n");	\
-      abort();						\
-    }
-
-
 #define NEED_LARGER_STACK	0
 
 
 void
 initialize_worker(int initial_num_threads, int maximum_num_threads,
-		  int num_modest_threads)
+		  int num_modest_threads, int num_loader_threads)
 {
   int i;
 #if NEED_LARGER_STACK
   size_t stack_size;
 #endif
   int initial_num_modest_threads;
+  int initial_num_loader_threads;
 
   job_list = NULL;
   worker_threads = NULL;
@@ -132,31 +114,9 @@ initialize_worker(int initial_num_threads, int maximum_num_threads,
       abort();
     }
 
-  if (pthread_mutex_init(&job_list_lock, NULL) != 0)
-    {
-      fprintf(stderr, "Couldn't init a mutex.\n");
-      abort();
-    }
-
-  if (pthread_cond_init(&idle_threads, NULL) != 0)
-    {
-      fprintf(stderr, "Couldn't init a condition variable.\n");
-      abort();
-    }
-
-
-  if (pthread_mutex_init(&modest_job_list_lock, NULL) != 0)
-    {
-      fprintf(stderr, "Couldn't init a mutex.\n");
-      abort();
-    }
-
-  if (pthread_cond_init(&idle_modest_threads, NULL) != 0)
-    {
-      fprintf(stderr, "Couldn't init a condition variable.\n");
-      abort();
-    }
-
+  normal_job_monitor = ochusha_monitor_new(NULL);
+  modest_job_monitor = ochusha_monitor_new(NULL);
+  loader_job_monitor = ochusha_monitor_new(NULL);
 
   if (pthread_attr_init(&worker_thread_attribute) != 0)
     {
@@ -193,6 +153,16 @@ initialize_worker(int initial_num_threads, int maximum_num_threads,
 
   for (i = 0; i < initial_num_modest_threads; i++)
     modest_worker_thread_new();
+
+  if (num_loader_threads > 0)
+    initial_num_loader_threads = MIN(num_loader_threads, 4);
+  else
+    initial_num_loader_threads = 0;
+
+  maximum_number_of_loader_threads = num_loader_threads;
+
+  for (i = 0; i < initial_num_loader_threads; i++)
+    loader_worker_thread_new();
 }
 
 
@@ -212,6 +182,9 @@ terminate_workers(void)
 
   g_slist_foreach((GSList *)modest_worker_threads,
 		  set_die_now_command_for_all_threads, NULL);
+
+  g_slist_foreach((GSList *)loader_worker_threads,
+		  set_die_now_command_for_all_threads, NULL);
 }
 
 
@@ -227,15 +200,7 @@ join_workers(void)
 					   list_entry);
       thread = (WorkerThread *)list_entry->data;
       g_slist_free_1(list_entry);
-      JOB_LIST_LOCK
-      {
-	if (pthread_cond_broadcast(&idle_threads) != 0)
-	  {
-	    fprintf(stderr, "Couldn't broadcast a condition variable.\n");
-	    abort();
-	  }
-      }
-      JOB_LIST_UNLOCK;
+      ochusha_monitor_notify_all(normal_job_monitor);
 
       if (pthread_join(thread->id, NULL) != 0)
 	{
@@ -245,7 +210,8 @@ join_workers(void)
 
       G_FREE(thread);
     }
-
+  ochusha_monitor_free(normal_job_monitor);
+  normal_job_monitor = NULL;
 
   while ((list_entry = (GSList *)modest_worker_threads) != NULL)
     {
@@ -254,15 +220,7 @@ join_workers(void)
 	= g_slist_remove_link((GSList *)modest_worker_threads, list_entry);
       thread = (WorkerThread *)list_entry->data;
       g_slist_free_1(list_entry);
-      MODEST_JOB_LIST_LOCK
-      {
-	if (pthread_cond_broadcast(&idle_modest_threads) != 0)
-	  {
-	    fprintf(stderr, "Couldn't broadcast a condition variable.\n");
-	    abort();
-	  }
-      }
-      MODEST_JOB_LIST_UNLOCK;
+      ochusha_monitor_notify_all(modest_job_monitor);
 
       if (pthread_join(thread->id, NULL) != 0)
 	{
@@ -272,6 +230,28 @@ join_workers(void)
 
       G_FREE(thread);
     }
+  ochusha_monitor_free(modest_job_monitor);
+  modest_job_monitor = NULL;
+
+  while ((list_entry = (GSList *)loader_worker_threads) != NULL)
+    {
+      WorkerThread *thread;
+      loader_worker_threads
+	= g_slist_remove_link((GSList *)loader_worker_threads, list_entry);
+      thread = (WorkerThread *)list_entry->data;
+      g_slist_free_1(list_entry);
+      ochusha_monitor_notify_all(loader_job_monitor);
+
+      if (pthread_join(thread->id, NULL) != 0)
+	{
+	  fprintf(stderr, "Couldn't join a thread\n");
+	  abort();
+	}
+
+      G_FREE(thread);
+    }
+  ochusha_monitor_free(loader_job_monitor);
+  loader_job_monitor = NULL;
 }
 
 
@@ -279,22 +259,31 @@ void
 cancel_pending_jobs(void)
 {
   GSList *tmp_list;
-  JOB_LIST_LOCK
-  {
-    tmp_list = (GSList *)job_list;
-    job_list = NULL;
-  }
-  JOB_LIST_UNLOCK;
 
+  ochusha_monitor_enter(normal_job_monitor);
+  tmp_list = (GSList *)job_list;
+  job_list = NULL;
+  ochusha_monitor_exit(normal_job_monitor);
+
+  g_slist_foreach(tmp_list, (GFunc)g_free, NULL);
   g_slist_free(tmp_list);
 
-  MODEST_JOB_LIST_LOCK
-  {
-    tmp_list = (GSList *)modest_job_list;
-    modest_job_list = NULL;
-  }
-  MODEST_JOB_LIST_UNLOCK;
 
+  ochusha_monitor_enter(modest_job_monitor);
+  tmp_list = (GSList *)modest_job_list;
+  modest_job_list = NULL;
+  ochusha_monitor_exit(modest_job_monitor);
+
+  g_slist_foreach(tmp_list, (GFunc)g_free, NULL);
+  g_slist_free(tmp_list);
+
+
+  ochusha_monitor_enter(loader_job_monitor);
+  tmp_list = (GSList *)loader_job_list;
+  loader_job_list = NULL;
+  ochusha_monitor_exit(loader_job_monitor);
+
+  g_slist_foreach(tmp_list, (GFunc)g_free, NULL);
   g_slist_free(tmp_list);
 }
 
@@ -322,7 +311,7 @@ worker_thread_new(void)
 void
 commit_job(WorkerJob *job)
 {
-  JOB_LIST_LOCK
+  ochusha_monitor_enter(normal_job_monitor);
   {
 
 #if DEBUG_THREAD_MOST
@@ -341,13 +330,8 @@ commit_job(WorkerJob *job)
 	fflush(stderr);
 #endif
 
-	if (pthread_cond_signal(&idle_threads) != 0)
-	  {
-	    fprintf(stderr, "Couldn't signal a condition variable.\n");
-	    abort();
-	  }
-
-	JOB_LIST_UNLOCK;
+	ochusha_monitor_notify(normal_job_monitor);
+	ochusha_monitor_exit(normal_job_monitor);
 #if DEBUG_THREAD_MOST
 	fprintf(stderr, "Job must be started!\n");
 	fflush(stderr);
@@ -363,7 +347,7 @@ commit_job(WorkerJob *job)
     if (number_of_threads < maximum_number_of_worker_threads)
       worker_thread_new();
   }
-  JOB_LIST_UNLOCK;
+  ochusha_monitor_exit(normal_job_monitor);
 }
 
 
@@ -371,7 +355,7 @@ static void *
 worker_thread_main(void *args)
 {
   WorkerThread *self = (WorkerThread *)args;
-  JOB_LIST_LOCK
+  ochusha_monitor_enter(normal_job_monitor);
   {
 #if DEBUG_THREAD_MOST
     fprintf(stderr, "WorkerThread is created.\n");
@@ -384,7 +368,7 @@ worker_thread_main(void *args)
 	WorkerJob *job;
 	if (self->command == DIE_NOW)
 	  {
-	    JOB_LIST_UNLOCK;
+	    ochusha_monitor_exit(normal_job_monitor);
 #if DEBUG_THREAD_MOST
 	    fprintf(stderr, "WorkerThread is killed.\n");
 	    fflush(stderr);
@@ -400,7 +384,7 @@ worker_thread_main(void *args)
 	    fflush(stderr);
 #endif
 	    number_of_idle_threads++;
-	    pthread_cond_wait(&idle_threads, &job_list_lock);
+	    ochusha_monitor_wait(normal_job_monitor);
 	    continue;
 	  }
 
@@ -408,11 +392,12 @@ worker_thread_main(void *args)
 	job = (WorkerJob *)list_entry->data;
 	g_slist_free_1(list_entry);
 
-	JOB_LIST_UNLOCK;
+	ochusha_monitor_exit(normal_job_monitor);
 
 	(*job->job)(self, job->args);
 	G_FREE(job);
-	JOB_LIST_LOCK;
+
+	ochusha_monitor_enter(normal_job_monitor);
       }
   }
 }
@@ -448,7 +433,7 @@ commit_modest_job(WorkerJob *job)
       return;
     }
 
-  MODEST_JOB_LIST_LOCK
+  ochusha_monitor_enter(modest_job_monitor);
   {
 
 #if DEBUG_THREAD_MOST
@@ -466,14 +451,8 @@ commit_modest_job(WorkerJob *job)
 	fprintf(stderr, "signaling to awake idle thread.\n");
 	fflush(stderr);
 #endif
-
-	if (pthread_cond_signal(&idle_modest_threads) != 0)
-	  {
-	    fprintf(stderr, "Couldn't signal a condition variable.\n");
-	    abort();
-	  }
-
-	MODEST_JOB_LIST_UNLOCK;
+	ochusha_monitor_notify(modest_job_monitor);
+	ochusha_monitor_exit(modest_job_monitor);
 #if DEBUG_THREAD_MOST
 	fprintf(stderr, "Job must be started!\n");
 	fflush(stderr);
@@ -489,7 +468,7 @@ commit_modest_job(WorkerJob *job)
     if (number_of_modest_threads < maximum_number_of_modest_threads)
       modest_worker_thread_new();
   }
-  MODEST_JOB_LIST_UNLOCK;
+  ochusha_monitor_exit(modest_job_monitor);
 }
 
 
@@ -497,7 +476,7 @@ static void *
 modest_worker_thread_main(void *args)
 {
   WorkerThread *self = (WorkerThread *)args;
-  MODEST_JOB_LIST_LOCK
+  ochusha_monitor_enter(modest_job_monitor);
   {
 #if DEBUG_THREAD_MOST
     fprintf(stderr, "WorkerThread is created.\n");
@@ -510,7 +489,7 @@ modest_worker_thread_main(void *args)
 	WorkerJob *job;
 	if (self->command == DIE_NOW)
 	  {
-	    MODEST_JOB_LIST_UNLOCK;
+	    ochusha_monitor_exit(modest_job_monitor);
 #if DEBUG_THREAD_MOST
 	    fprintf(stderr, "WorkerThread is killed.\n");
 	    fflush(stderr);
@@ -526,7 +505,7 @@ modest_worker_thread_main(void *args)
 	    fflush(stderr);
 #endif
 	    number_of_idle_modest_threads++;
-	    pthread_cond_wait(&idle_modest_threads, &modest_job_list_lock);
+	    ochusha_monitor_wait(modest_job_monitor);
 	    continue;
 	  }
 
@@ -535,11 +514,134 @@ modest_worker_thread_main(void *args)
 	job = (WorkerJob *)list_entry->data;
 	g_slist_free_1(list_entry);
 
-	MODEST_JOB_LIST_UNLOCK;
+	ochusha_monitor_exit(modest_job_monitor);
 
 	(*job->job)(self, job->args);
 	G_FREE(job);
-	MODEST_JOB_LIST_LOCK;
+
+	ochusha_monitor_enter(modest_job_monitor);
+      }
+  }
+}
+
+
+static WorkerThread *
+loader_worker_thread_new(void)
+{
+  WorkerThread *thread = G_NEW0(WorkerThread, 1);
+  thread->command = GO_AHEAD;
+
+  if (pthread_create(&thread->id, &worker_thread_attribute,
+		     loader_worker_thread_main, thread) != 0)
+    {
+      fprintf(stderr, "Couldn't create a worker thread.\n");
+      abort();
+    }
+
+  loader_worker_threads
+    = g_slist_append((GSList *)loader_worker_threads, thread);
+  number_of_loader_threads++;
+
+  return thread;
+}
+
+
+void
+commit_loader_job(WorkerJob *job)
+{
+  if (maximum_number_of_loader_threads <= 0)
+    {
+      commit_job(job);
+      return;
+    }
+
+  ochusha_monitor_enter(loader_job_monitor);
+  {
+
+#if DEBUG_THREAD_MOST
+    fprintf(stderr, "commit_job: job committed.\n");
+    fflush(stderr);
+#endif
+
+    loader_job_list = g_slist_append((GSList *)loader_job_list, job);
+
+    if (number_of_idle_loader_threads > 0)
+      {
+	number_of_idle_loader_threads--;
+
+#if DEBUG_THREAD_MOST
+	fprintf(stderr, "signaling to awake idle thread.\n");
+	fflush(stderr);
+#endif
+	ochusha_monitor_notify(loader_job_monitor);
+	ochusha_monitor_exit(loader_job_monitor);
+#if DEBUG_THREAD_MOST
+	fprintf(stderr, "Job must be started!\n");
+	fflush(stderr);
+#endif
+	return;
+      }
+
+#if DEBUG_THREAD_MOST
+    fprintf(stderr, "There's no idle thread.\n");
+    fflush(stderr);
+#endif
+
+    if (number_of_loader_threads < maximum_number_of_loader_threads)
+      loader_worker_thread_new();
+  }
+  ochusha_monitor_exit(loader_job_monitor);
+}
+
+
+static void *
+loader_worker_thread_main(void *args)
+{
+  WorkerThread *self = (WorkerThread *)args;
+  ochusha_monitor_enter(loader_job_monitor);
+  {
+#if DEBUG_THREAD_MOST
+    fprintf(stderr, "WorkerThread is created.\n");
+    fflush(stderr);
+#endif
+
+    while (1)
+      {
+	GSList *list_entry;
+	WorkerJob *job;
+	if (self->command == DIE_NOW)
+	  {
+	    ochusha_monitor_exit(loader_job_monitor);
+#if DEBUG_THREAD_MOST
+	    fprintf(stderr, "WorkerThread is killed.\n");
+	    fflush(stderr);
+#endif
+	    pthread_exit(NULL);
+	  }
+
+	list_entry = (GSList *)loader_job_list;
+	if (list_entry == NULL)
+	  {
+#if DEBUG_THREAD_MOST
+	    fprintf(stderr, "There's no job to be done.\n");
+	    fflush(stderr);
+#endif
+	    number_of_idle_loader_threads++;
+	    ochusha_monitor_wait(loader_job_monitor);
+	    continue;
+	  }
+
+	loader_job_list
+	  = g_slist_remove_link((GSList *)loader_job_list, list_entry);
+	job = (WorkerJob *)list_entry->data;
+	g_slist_free_1(list_entry);
+
+	ochusha_monitor_exit(loader_job_monitor);
+
+	(*job->job)(self, job->args);
+	G_FREE(job);
+
+	ochusha_monitor_enter(loader_job_monitor);
       }
   }
 }
