@@ -2,7 +2,7 @@
 
   sjis.c -  Oniguruma (regular expression library)
 
-  Copyright (C) 2003-2004  K.Kosako (kosako AT sofnec DOT co DOT jp)
+  Copyright (C) 2003-2004  K.Kosako (sndgk393 AT ybb DOT ne DOT jp)
 
 **********************************************************************/
 #include "regenc.h"
@@ -88,22 +88,16 @@ sjis_mbc_to_lower(UChar* p, UChar* lower)
 static int
 sjis_code_is_ctype(OnigCodePoint code, unsigned int ctype)
 {
-  if ((ctype & ONIGENC_CTYPE_WORD) != 0) {
-    if (code < 128)
-      return ONIGENC_IS_ASCII_CODE_CTYPE(code, ctype);
-    else {
-      int first = onigenc_mb2_code_to_mbc_first(code);
-      return (enc_len(ONIG_ENCODING_SJIS, first) > 1 ? TRUE : FALSE);
-    }
-
-    ctype &= ~ONIGENC_CTYPE_WORD;
-    if (ctype == 0) return FALSE;
-  }
-
   if (code < 128)
     return ONIGENC_IS_ASCII_CODE_CTYPE(code, ctype);
-  else
-    return FALSE;
+  else {
+    if ((ctype & (ONIGENC_CTYPE_WORD |
+                  ONIGENC_CTYPE_GRAPH | ONIGENC_CTYPE_PRINT)) != 0) {
+      return (onigenc_mb2_code_to_mbclen(code) > 1 ? TRUE : FALSE);
+    }
+  }
+
+  return FALSE;
 }
 
 static UChar*
