@@ -2,12 +2,16 @@
 
   oniggnu.h - Oniguruma (regular expression library)
 
-  Copyright (C) 2004  K.Kosako (kosako AT sofnec DOT co DOT jp)
+  Copyright (C) 2005  K.Kosako (sndgk393 AT ybb DOT ne DOT jp)
 
 **********************************************************************/
 #ifndef ONIGGNU_H
 #define ONIGGNU_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #include "oniguruma.h"
 
 #define MBCTYPE_ASCII         0
@@ -74,4 +78,8 @@ void re_free_registers P_((struct re_registers*));
 ONIG_EXTERN
 int re_alloc_pattern P_((struct re_pattern_buffer**));  /* added */
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* ONIGGNU_H */
