@@ -2,16 +2,29 @@
 
   oniguruma.h - Oniguruma (regular expression library)
 
-  Copyright (C) 2002-2004  K.Kosako (kosako@sofnec.co.jp)
+  Copyright (C) 2002-2005  K.Kosako (sndgk393 AT ybb DOT ne DOT jp)
 
 **********************************************************************/
 #ifndef ONIGURUMA_H
 #define ONIGURUMA_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #define ONIGURUMA
 #define ONIGURUMA_VERSION_MAJOR   2
-#define ONIGURUMA_VERSION_MINOR   2
-#define ONIGURUMA_VERSION_TEENY   8
+#define ONIGURUMA_VERSION_MINOR   4
+#define ONIGURUMA_VERSION_TEENY   4
+
+#ifdef __cplusplus
+# ifndef  HAVE_PROTOTYPES
+#  define HAVE_PROTOTYPES 1
+# endif
+# ifndef  HAVE_STDARG_PROTOTYPES
+#  define HAVE_STDARG_PROTOTYPES 1
+# endif
+#endif
 
 #ifndef P_
 #if defined(__STDC__) || defined(_WIN32)
@@ -724,4 +737,8 @@ int onig_end P_((void));
 ONIG_EXTERN
 const char* onig_version P_((void));
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* ONIGURUMA_H */
