@@ -2,7 +2,7 @@
 
   regenc.c -  Oniguruma (regular expression library)
 
-  Copyright (C) 2003-2004  K.Kosako (kosako AT sofnec DOT co DOT jp)
+  Copyright (C) 2003-2004  K.Kosako (sndgk393 AT ybb DOT ne DOT jp)
 
 **********************************************************************/
 #include "regenc.h"
@@ -224,11 +224,13 @@ onigenc_single_byte_code_to_mbclen(OnigCodePoint code)
   return 1;
 }
 
+#if 0
 extern int
 onigenc_single_byte_code_to_mbc_first(OnigCodePoint code)
 {
   return (code & 0xff);
 }
+#endif
 
 extern int
 onigenc_single_byte_code_to_mbc(OnigCodePoint code, UChar *buf)
@@ -315,6 +317,7 @@ onigenc_mb4_code_to_mbclen(OnigCodePoint code)
   else return 1;
 }
 
+#if 0
 extern int
 onigenc_mb2_code_to_mbc_first(OnigCodePoint code)
 {
@@ -348,6 +351,7 @@ onigenc_mb4_code_to_mbc_first(OnigCodePoint code)
   }
   return first;
 }
+#endif
 
 extern int
 onigenc_mb2_code_to_mbc(OnigEncoding enc, OnigCodePoint code, UChar *buf)
@@ -374,10 +378,10 @@ onigenc_mb4_code_to_mbc(OnigEncoding enc, OnigCodePoint code, UChar *buf)
   if ((code & 0xff000000) != 0) {
     *p++ = (UChar )((code >> 24) & 0xff);
   }
-  if ((code & 0xff0000) != 0) {
+  if ((code & 0xff0000) != 0 || p != buf) {
     *p++ = (UChar )((code >> 16) & 0xff);
   }
-  if ((code & 0xff00) != 0) {
+  if ((code & 0xff00) != 0 || p != buf) {
     *p++ = (UChar )((code >> 8) & 0xff);
   }
   *p++ = (UChar )(code & 0xff);
@@ -393,44 +397,32 @@ extern int
 onigenc_mb2_code_is_ctype(OnigEncoding enc, OnigCodePoint code,
 			  unsigned int ctype)
 {
-  if ((ctype & ONIGENC_CTYPE_WORD) != 0) {
-    if (code < 128)
-      return ONIGENC_IS_ASCII_CODE_CTYPE(code, ctype);
-    else {
-      int first = onigenc_mb2_code_to_mbc_first(code);
-      return (enc_len(enc, first) > 1 ? TRUE : FALSE);
-    }
-
-    ctype &= ~ONIGENC_CTYPE_WORD;
-    if (ctype == 0) return FALSE;
-  }
-
   if (code < 128)
     return ONIGENC_IS_ASCII_CODE_CTYPE(code, ctype);
-  else
-    return FALSE;
+  else {
+    if ((ctype & (ONIGENC_CTYPE_WORD |
+                  ONIGENC_CTYPE_GRAPH | ONIGENC_CTYPE_PRINT)) != 0) {
+      return (onigenc_mb2_code_to_mbclen(code) > 1 ? TRUE : FALSE);
+    }
+  }
+
+  return FALSE;
 }
 
 extern int
 onigenc_mb4_code_is_ctype(OnigEncoding enc, OnigCodePoint code,
 			  unsigned int ctype)
 {
-  if ((ctype & ONIGENC_CTYPE_WORD) != 0) {
-    if (code < 128)
-      return ONIGENC_IS_ASCII_CODE_CTYPE(code, ctype);
-    else {
-      int first = onigenc_mb4_code_to_mbc_first(code);
-      return (enc_len(enc, first) > 1 ? TRUE : FALSE);
-    }
-
-    ctype &= ~ONIGENC_CTYPE_WORD;
-    if (ctype == 0) return FALSE;
-  }
-
   if (code < 128)
     return ONIGENC_IS_ASCII_CODE_CTYPE(code, ctype);
-  else
-    return FALSE;
+  else {
+    if ((ctype & (ONIGENC_CTYPE_WORD |
+                  ONIGENC_CTYPE_GRAPH | ONIGENC_CTYPE_PRINT)) != 0) {
+      return (onigenc_mb4_code_to_mbclen(code) > 1 ? TRUE : FALSE);
+    }
+  }
+
+  return FALSE;
 }
 
 extern int
