@@ -2,7 +2,7 @@
 
   regexec.c -  Oniguruma (regular expression library)
 
-  Copyright (C) 2002-2004  K.Kosako (kosako AT sofnec DOT co DOT jp)
+  Copyright (C) 2002-2005  K.Kosako (sndgk393 AT ybb DOT ne DOT jp)
 
 **********************************************************************/
 #include "regint.h"
@@ -3188,8 +3188,10 @@ onig_search(regex_t* reg, UChar* str, UChar* end,
       }
     }
     else if (reg->anchor & ANCHOR_SEMI_END_BUF) {
-      if (ONIG_IS_NEWLINE(end[-1])) {
-	semi_end = end - 1;
+      UChar* pre_end = ONIGENC_STEP_BACK(reg->enc, str, end, 1);
+
+      if (ONIG_IS_NEWLINE(*pre_end)) {
+	semi_end = pre_end;
 	if (semi_end > str && start <= semi_end) {
 	  goto end_buf;
 	}
@@ -3247,8 +3249,11 @@ onig_search(regex_t* reg, UChar* str, UChar* end,
 	  if (sch_range > end) sch_range = end;
 	}
       }
-      if (reg->dmax != ONIG_INFINITE_DISTANCE &&
-	  (end - start) >= reg->threshold_len) {
+
+      if ((end - start) < reg->threshold_len)
+        goto mismatch;
+
+      if (reg->dmax != ONIG_INFINITE_DISTANCE) {
 	do {
 	  if (! forward_search_range(reg, str, end, s, sch_range,
 				     &low, &high, &low_prev)) goto mismatch;
@@ -3261,21 +3266,26 @@ onig_search(regex_t* reg, UChar* str, UChar* end,
 	    prev = s;
 	    s += enc_len(reg->enc, *s);
 	  }
-	  if ((reg->anchor & ANCHOR_ANYCHAR_STAR) != 0) {
-	    if (IS_NOT_NULL(prev)) {
-	      while (!ONIG_IS_NEWLINE(*prev) && s < range) {
-		prev = s;
-		s += enc_len(reg->enc, *s);
-	      }
-	    }
-	  }
 	} while (s < range);
 	goto mismatch;
       }
       else { /* check only. */
-	if ((end - start) < reg->threshold_len ||
-	    ! forward_search_range(reg, str, end, s, sch_range,
+        if (! forward_search_range(reg, str, end, s, sch_range,
 				   &low, &high, (UChar** )NULL)) goto mismatch;
+
+        if ((reg->anchor & ANCHOR_ANYCHAR_STAR) != 0) {
+          do {
+            MATCH_AND_RETURN_CHECK;
+            prev = s;
+            s += enc_len(reg->enc, *s);
+
+            while (!ONIG_IS_NEWLINE(*prev) && s < range) {
+              prev = s;
+              s += enc_len(reg->enc, *s);
+            }
+          } while (s < range);
+          goto mismatch;
+        }
       }
     }
 
