@@ -2,7 +2,7 @@
 
   regparse.h -  Oniguruma (regular expression library)
 
-  Copyright (C) 2003-2004  K.Kosako (kosako AT sofnec DOT co DOT jp)
+  Copyright (C) 2003-2005  K.Kosako (sndgk393 AT ybb DOT ne DOT jp)
 
 **********************************************************************/
 #ifndef REGPARSE_H
@@ -255,6 +255,14 @@ typedef struct {
 #define IS_SYNTAX_OP2(syn, opm)   (((syn)->op2 & (opm)) != 0)
 #define IS_SYNTAX_BV(syn, bvm)    (((syn)->behavior & (bvm)) != 0)
 
+#ifdef USE_NAMED_GROUP
+typedef struct {
+  int new_val;
+} GroupNumRemap;
+
+extern int    onig_renumber_name_table P_((regex_t* reg, GroupNumRemap* map));
+#endif
+
 extern int    onig_is_code_in_cc P_((OnigEncoding enc, OnigCodePoint code, CClassNode* cc));
 extern int    onig_strncmp P_((UChar* s1, UChar* s2, int n));
 extern void   onig_scan_env_set_error_string P_((ScanEnv* env, int ecode, UChar* arg, UChar* arg_end));
