@@ -2,7 +2,7 @@
 
   regposix.c - Oniguruma (regular expression library)
 
-  Copyright (C) 2003-2004  K.Kosako (kosako AT sofnec DOT co DOT jp)
+  Copyright (C) 2003-2004  K.Kosako (sndgk393 AT ybb DOT ne DOT jp)
 
 **********************************************************************/
 
@@ -156,7 +156,7 @@ regexec(regex_t* reg, const char* str, size_t nmatch,
     pm = (regmatch_t* )NULL;
     nmatch = 0;
   }
-  else if (nmatch < ONIG_C(reg)->num_mem + 1) {
+  else if ((int )nmatch < ONIG_C(reg)->num_mem + 1) {
     pm = (regmatch_t* )xmalloc(sizeof(regmatch_t)
                                * (ONIG_C(reg)->num_mem + 1));
     if (pm == NULL)
